<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'Bamarni\\Composer\\Bin\\ApplicationFactory\\FreshInstanceApplicationFactory' => $vendorDir . '/bamarni/composer-bin-plugin/src/ApplicationFactory/FreshInstanceApplicationFactory.php',
    'Bamarni\\Composer\\Bin\\ApplicationFactory\\NamespaceApplicationFactory' => $vendorDir . '/bamarni/composer-bin-plugin/src/ApplicationFactory/NamespaceApplicationFactory.php',
    'Bamarni\\Composer\\Bin\\BamarniBinPlugin' => $vendorDir . '/bamarni/composer-bin-plugin/src/BamarniBinPlugin.php',
    'Bamarni\\Composer\\Bin\\CommandProvider' => $vendorDir . '/bamarni/composer-bin-plugin/src/CommandProvider.php',
    'Bamarni\\Composer\\Bin\\Command\\BinCommand' => $vendorDir . '/bamarni/composer-bin-plugin/src/Command/BinCommand.php',
    'Bamarni\\Composer\\Bin\\Command\\CouldNotCreateNamespaceDir' => $vendorDir . '/bamarni/composer-bin-plugin/src/Command/CouldNotCreateNamespaceDir.php',
    'Bamarni\\Composer\\Bin\\Config\\Config' => $vendorDir . '/bamarni/composer-bin-plugin/src/Config/Config.php',
    'Bamarni\\Composer\\Bin\\Config\\ConfigFactory' => $vendorDir . '/bamarni/composer-bin-plugin/src/Config/ConfigFactory.php',
    'Bamarni\\Composer\\Bin\\Config\\InvalidBamarniComposerExtraConfig' => $vendorDir . '/bamarni/composer-bin-plugin/src/Config/InvalidBamarniComposerExtraConfig.php',
    'Bamarni\\Composer\\Bin\\Input\\BinInputFactory' => $vendorDir . '/bamarni/composer-bin-plugin/src/Input/BinInputFactory.php',
    'Bamarni\\Composer\\Bin\\Input\\InvalidBinInput' => $vendorDir . '/bamarni/composer-bin-plugin/src/Input/InvalidBinInput.php',
    'Bamarni\\Composer\\Bin\\Logger' => $vendorDir . '/bamarni/composer-bin-plugin/src/Logger.php',
    'Bamarni\\Composer\\Bin\\PublicIO' => $vendorDir . '/bamarni/composer-bin-plugin/src/PublicIO.php',
    'Composer\\InstalledVersions' => $vendorDir . '/composer/InstalledVersions.php',
    'OCA\\Talk\\Activity\\Listener' => $baseDir . '/lib/Activity/Listener.php',
    'OCA\\Talk\\Activity\\Provider\\Base' => $baseDir . '/lib/Activity/Provider/Base.php',
    'OCA\\Talk\\Activity\\Provider\\Call' => $baseDir . '/lib/Activity/Provider/Call.php',
    'OCA\\Talk\\Activity\\Provider\\Invitation' => $baseDir . '/lib/Activity/Provider/Invitation.php',
    'OCA\\Talk\\Activity\\Setting' => $baseDir . '/lib/Activity/Setting.php',
    'OCA\\Talk\\AppInfo\\Application' => $baseDir . '/lib/AppInfo/Application.php',
    'OCA\\Talk\\Authenticator' => $baseDir . '/lib/Authenticator.php',
    'OCA\\Talk\\BackgroundJob\\CheckCertificates' => $baseDir . '/lib/BackgroundJob/CheckCertificates.php',
    'OCA\\Talk\\BackgroundJob\\CheckHostedSignalingServer' => $baseDir . '/lib/BackgroundJob/CheckHostedSignalingServer.php',
    'OCA\\Talk\\BackgroundJob\\CheckMatterbridges' => $baseDir . '/lib/BackgroundJob/CheckMatterbridges.php',
    'OCA\\Talk\\BackgroundJob\\ExpireChatMessages' => $baseDir . '/lib/BackgroundJob/ExpireChatMessages.php',
    'OCA\\Talk\\BackgroundJob\\ExpireObjectRooms' => $baseDir . '/lib/BackgroundJob/ExpireObjectRooms.php',
    'OCA\\Talk\\BackgroundJob\\ExpireSignalingMessage' => $baseDir . '/lib/BackgroundJob/ExpireSignalingMessage.php',
    'OCA\\Talk\\BackgroundJob\\LockInactiveRooms' => $baseDir . '/lib/BackgroundJob/LockInactiveRooms.php',
    'OCA\\Talk\\BackgroundJob\\MaximumCallDuration' => $baseDir . '/lib/BackgroundJob/MaximumCallDuration.php',
    'OCA\\Talk\\BackgroundJob\\Reminder' => $baseDir . '/lib/BackgroundJob/Reminder.php',
    'OCA\\Talk\\BackgroundJob\\RemoveEmptyRooms' => $baseDir . '/lib/BackgroundJob/RemoveEmptyRooms.php',
    'OCA\\Talk\\BackgroundJob\\ResetAssignedSignalingServer' => $baseDir . '/lib/BackgroundJob/ResetAssignedSignalingServer.php',
    'OCA\\Talk\\BackgroundJob\\RetryNotificationsJob' => $baseDir . '/lib/BackgroundJob/RetryNotificationsJob.php',
    'OCA\\Talk\\BackgroundJob\\SendScheduledMessages' => $baseDir . '/lib/BackgroundJob/SendScheduledMessages.php',
    'OCA\\Talk\\BackgroundJob\\UnpinMessage' => $baseDir . '/lib/BackgroundJob/UnpinMessage.php',
    'OCA\\Talk\\CachePrefix' => $baseDir . '/lib/CachePrefix.php',
    'OCA\\Talk\\Capabilities' => $baseDir . '/lib/Capabilities.php',
    'OCA\\Talk\\Chat\\AutoComplete\\SearchPlugin' => $baseDir . '/lib/Chat/AutoComplete/SearchPlugin.php',
    'OCA\\Talk\\Chat\\AutoComplete\\Sorter' => $baseDir . '/lib/Chat/AutoComplete/Sorter.php',
    'OCA\\Talk\\Chat\\Changelog\\Listener' => $baseDir . '/lib/Chat/Changelog/Listener.php',
    'OCA\\Talk\\Chat\\Changelog\\Manager' => $baseDir . '/lib/Chat/Changelog/Manager.php',
    'OCA\\Talk\\Chat\\ChatManager' => $baseDir . '/lib/Chat/ChatManager.php',
    'OCA\\Talk\\Chat\\CommentsManager' => $baseDir . '/lib/Chat/CommentsManager.php',
    'OCA\\Talk\\Chat\\Listener' => $baseDir . '/lib/Chat/Listener.php',
    'OCA\\Talk\\Chat\\MessageParser' => $baseDir . '/lib/Chat/MessageParser.php',
    'OCA\\Talk\\Chat\\Notifier' => $baseDir . '/lib/Chat/Notifier.php',
    'OCA\\Talk\\Chat\\Parser\\Changelog' => $baseDir . '/lib/Chat/Parser/Changelog.php',
    'OCA\\Talk\\Chat\\Parser\\Command' => $baseDir . '/lib/Chat/Parser/Command.php',
    'OCA\\Talk\\Chat\\Parser\\PrivateReply' => $baseDir . '/lib/Chat/Parser/PrivateReply.php',
    'OCA\\Talk\\Chat\\Parser\\ReactionParser' => $baseDir . '/lib/Chat/Parser/ReactionParser.php',
    'OCA\\Talk\\Chat\\Parser\\SystemMessage' => $baseDir . '/lib/Chat/Parser/SystemMessage.php',
    'OCA\\Talk\\Chat\\Parser\\UserMention' => $baseDir . '/lib/Chat/Parser/UserMention.php',
    'OCA\\Talk\\Chat\\ReactionManager' => $baseDir . '/lib/Chat/ReactionManager.php',
    'OCA\\Talk\\Chat\\SystemMessage\\Listener' => $baseDir . '/lib/Chat/SystemMessage/Listener.php',
    'OCA\\Talk\\Collaboration\\Collaborators\\Listener' => $baseDir . '/lib/Collaboration/Collaborators/Listener.php',
    'OCA\\Talk\\Collaboration\\Collaborators\\RoomPlugin' => $baseDir . '/lib/Collaboration/Collaborators/RoomPlugin.php',
    'OCA\\Talk\\Collaboration\\Reference\\ReferenceInvalidationListener' => $baseDir . '/lib/Collaboration/Reference/ReferenceInvalidationListener.php',
    'OCA\\Talk\\Collaboration\\Reference\\TalkReferenceProvider' => $baseDir . '/lib/Collaboration/Reference/TalkReferenceProvider.php',
    'OCA\\Talk\\Collaboration\\Resources\\ConversationProvider' => $baseDir . '/lib/Collaboration/Resources/ConversationProvider.php',
    'OCA\\Talk\\Collaboration\\Resources\\Listener' => $baseDir . '/lib/Collaboration/Resources/Listener.php',
    'OCA\\Talk\\Command\\Bot\\Create' => $baseDir . '/lib/Command/Bot/Create.php',
    'OCA\\Talk\\Command\\Bot\\Install' => $baseDir . '/lib/Command/Bot/Install.php',
    'OCA\\Talk\\Command\\Bot\\ListBots' => $baseDir . '/lib/Command/Bot/ListBots.php',
    'OCA\\Talk\\Command\\Bot\\Remove' => $baseDir . '/lib/Command/Bot/Remove.php',
    'OCA\\Talk\\Command\\Bot\\Setup' => $baseDir . '/lib/Command/Bot/Setup.php',
    'OCA\\Talk\\Command\\Bot\\State' => $baseDir . '/lib/Command/Bot/State.php',
    'OCA\\Talk\\Command\\Bot\\Uninstall' => $baseDir . '/lib/Command/Bot/Uninstall.php',
    'OCA\\Talk\\Command\\Developer\\AgeChatMessages' => $baseDir . '/lib/Command/Developer/AgeChatMessages.php',
    'OCA\\Talk\\Command\\Developer\\UpdateDocs' => $baseDir . '/lib/Command/Developer/UpdateDocs.php',
    'OCA\\Talk\\Command\\Monitor\\Calls' => $baseDir . '/lib/Command/Monitor/Calls.php',
    'OCA\\Talk\\Command\\Monitor\\HasActiveCalls' => $baseDir . '/lib/Command/Monitor/HasActiveCalls.php',
    'OCA\\Talk\\Command\\Monitor\\Room' => $baseDir . '/lib/Command/Monitor/Room.php',
    'OCA\\Talk\\Command\\PhoneNumber\\AddPhoneNumber' => $baseDir . '/lib/Command/PhoneNumber/AddPhoneNumber.php',
    'OCA\\Talk\\Command\\PhoneNumber\\FindPhoneNumber' => $baseDir . '/lib/Command/PhoneNumber/FindPhoneNumber.php',
    'OCA\\Talk\\Command\\PhoneNumber\\ImportPhoneNumbers' => $baseDir . '/lib/Command/PhoneNumber/ImportPhoneNumbers.php',
    'OCA\\Talk\\Command\\PhoneNumber\\RemovePhoneNumber' => $baseDir . '/lib/Command/PhoneNumber/RemovePhoneNumber.php',
    'OCA\\Talk\\Command\\PhoneNumber\\RemoveUser' => $baseDir . '/lib/Command/PhoneNumber/RemoveUser.php',
    'OCA\\Talk\\Command\\Recording\\Consent' => $baseDir . '/lib/Command/Recording/Consent.php',
    'OCA\\Talk\\Command\\Room\\Add' => $baseDir . '/lib/Command/Room/Add.php',
    'OCA\\Talk\\Command\\Room\\Create' => $baseDir . '/lib/Command/Room/Create.php',
    'OCA\\Talk\\Command\\Room\\Delete' => $baseDir . '/lib/Command/Room/Delete.php',
    'OCA\\Talk\\Command\\Room\\Demote' => $baseDir . '/lib/Command/Room/Demote.php',
    'OCA\\Talk\\Command\\Room\\Promote' => $baseDir . '/lib/Command/Room/Promote.php',
    'OCA\\Talk\\Command\\Room\\Remove' => $baseDir . '/lib/Command/Room/Remove.php',
    'OCA\\Talk\\Command\\Room\\TRoomCommand' => $baseDir . '/lib/Command/Room/TRoomCommand.php',
    'OCA\\Talk\\Command\\Room\\Update' => $baseDir . '/lib/Command/Room/Update.php',
    'OCA\\Talk\\Command\\Signaling\\Add' => $baseDir . '/lib/Command/Signaling/Add.php',
    'OCA\\Talk\\Command\\Signaling\\Delete' => $baseDir . '/lib/Command/Signaling/Delete.php',
    'OCA\\Talk\\Command\\Signaling\\ListCommand' => $baseDir . '/lib/Command/Signaling/ListCommand.php',
    'OCA\\Talk\\Command\\Signaling\\VerifyKeys' => $baseDir . '/lib/Command/Signaling/VerifyKeys.php',
    'OCA\\Talk\\Command\\Stun\\Add' => $baseDir . '/lib/Command/Stun/Add.php',
    'OCA\\Talk\\Command\\Stun\\Delete' => $baseDir . '/lib/Command/Stun/Delete.php',
    'OCA\\Talk\\Command\\Stun\\ListCommand' => $baseDir . '/lib/Command/Stun/ListCommand.php',
    'OCA\\Talk\\Command\\Turn\\Add' => $baseDir . '/lib/Command/Turn/Add.php',
    'OCA\\Talk\\Command\\Turn\\Delete' => $baseDir . '/lib/Command/Turn/Delete.php',
    'OCA\\Talk\\Command\\Turn\\ListCommand' => $baseDir . '/lib/Command/Turn/ListCommand.php',
    'OCA\\Talk\\Command\\User\\Remove' => $baseDir . '/lib/Command/User/Remove.php',
    'OCA\\Talk\\Command\\User\\TransferOwnership' => $baseDir . '/lib/Command/User/TransferOwnership.php',
    'OCA\\Talk\\Config' => $baseDir . '/lib/Config.php',
    'OCA\\Talk\\ConfigLexicon' => $baseDir . '/lib/ConfigLexicon.php',
    'OCA\\Talk\\ContactsMenu\\Providers\\CallProvider' => $baseDir . '/lib/ContactsMenu/Providers/CallProvider.php',
    'OCA\\Talk\\Controller\\AEnvironmentAwareOCSController' => $baseDir . '/lib/Controller/AEnvironmentAwareOCSController.php',
    'OCA\\Talk\\Controller\\AvatarController' => $baseDir . '/lib/Controller/AvatarController.php',
    'OCA\\Talk\\Controller\\BanController' => $baseDir . '/lib/Controller/BanController.php',
    'OCA\\Talk\\Controller\\BotController' => $baseDir . '/lib/Controller/BotController.php',
    'OCA\\Talk\\Controller\\BreakoutRoomController' => $baseDir . '/lib/Controller/BreakoutRoomController.php',
    'OCA\\Talk\\Controller\\CalendarIntegrationController' => $baseDir . '/lib/Controller/CalendarIntegrationController.php',
    'OCA\\Talk\\Controller\\CallController' => $baseDir . '/lib/Controller/CallController.php',
    'OCA\\Talk\\Controller\\CallNotificationController' => $baseDir . '/lib/Controller/CallNotificationController.php',
    'OCA\\Talk\\Controller\\CertificateController' => $baseDir . '/lib/Controller/CertificateController.php',
    'OCA\\Talk\\Controller\\ChatController' => $baseDir . '/lib/Controller/ChatController.php',
    'OCA\\Talk\\Controller\\ConversationTagController' => $baseDir . '/lib/Controller/ConversationTagController.php',
    'OCA\\Talk\\Controller\\FederationController' => $baseDir . '/lib/Controller/FederationController.php',
    'OCA\\Talk\\Controller\\FilesIntegrationController' => $baseDir . '/lib/Controller/FilesIntegrationController.php',
    'OCA\\Talk\\Controller\\GuestController' => $baseDir . '/lib/Controller/GuestController.php',
    'OCA\\Talk\\Controller\\HostedSignalingServerController' => $baseDir . '/lib/Controller/HostedSignalingServerController.php',
    'OCA\\Talk\\Controller\\LiveTranscriptionController' => $baseDir . '/lib/Controller/LiveTranscriptionController.php',
    'OCA\\Talk\\Controller\\MatterbridgeController' => $baseDir . '/lib/Controller/MatterbridgeController.php',
    'OCA\\Talk\\Controller\\MatterbridgeSettingsController' => $baseDir . '/lib/Controller/MatterbridgeSettingsController.php',
    'OCA\\Talk\\Controller\\PageController' => $baseDir . '/lib/Controller/PageController.php',
    'OCA\\Talk\\Controller\\PollController' => $baseDir . '/lib/Controller/PollController.php',
    'OCA\\Talk\\Controller\\PresetController' => $baseDir . '/lib/Controller/PresetController.php',
    'OCA\\Talk\\Controller\\PublicShareAuthController' => $baseDir . '/lib/Controller/PublicShareAuthController.php',
    'OCA\\Talk\\Controller\\ReactionController' => $baseDir . '/lib/Controller/ReactionController.php',
    'OCA\\Talk\\Controller\\RecordingController' => $baseDir . '/lib/Controller/RecordingController.php',
    'OCA\\Talk\\Controller\\RoomController' => $baseDir . '/lib/Controller/RoomController.php',
    'OCA\\Talk\\Controller\\SettingsController' => $baseDir . '/lib/Controller/SettingsController.php',
    'OCA\\Talk\\Controller\\SignalingController' => $baseDir . '/lib/Controller/SignalingController.php',
    'OCA\\Talk\\Controller\\TempAvatarController' => $baseDir . '/lib/Controller/TempAvatarController.php',
    'OCA\\Talk\\Controller\\ThreadController' => $baseDir . '/lib/Controller/ThreadController.php',
    'OCA\\Talk\\Dashboard\\Event' => $baseDir . '/lib/Dashboard/Event.php',
    'OCA\\Talk\\Dashboard\\TalkWidget' => $baseDir . '/lib/Dashboard/TalkWidget.php',
    'OCA\\Talk\\DataObjects\\AccountId' => $baseDir . '/lib/DataObjects/AccountId.php',
    'OCA\\Talk\\DataObjects\\RegisterAccountData' => $baseDir . '/lib/DataObjects/RegisterAccountData.php',
    'OCA\\Talk\\Deck\\DeckPluginLoader' => $baseDir . '/lib/Deck/DeckPluginLoader.php',
    'OCA\\Talk\\Events\\AAttendeeRemovedEvent' => $baseDir . '/lib/Events/AAttendeeRemovedEvent.php',
    'OCA\\Talk\\Events\\ABeforeJoinedRoomEvent' => $baseDir . '/lib/Events/ABeforeJoinedRoomEvent.php',
    'OCA\\Talk\\Events\\ACallEndedEvent' => $baseDir . '/lib/Events/ACallEndedEvent.php',
    'OCA\\Talk\\Events\\ACallEndedForEveryoneEvent' => $baseDir . '/lib/Events/ACallEndedForEveryoneEvent.php',
    'OCA\\Talk\\Events\\ACallStartedEvent' => $baseDir . '/lib/Events/ACallStartedEvent.php',
    'OCA\\Talk\\Events\\ALobbyModifiedEvent' => $baseDir . '/lib/Events/ALobbyModifiedEvent.php',
    'OCA\\Talk\\Events\\AMessageSentEvent' => $baseDir . '/lib/Events/AMessageSentEvent.php',
    'OCA\\Talk\\Events\\AParticipantModifiedEvent' => $baseDir . '/lib/Events/AParticipantModifiedEvent.php',
    'OCA\\Talk\\Events\\AReactionEvent' => $baseDir . '/lib/Events/AReactionEvent.php',
    'OCA\\Talk\\Events\\ARoomEvent' => $baseDir . '/lib/Events/ARoomEvent.php',
    'OCA\\Talk\\Events\\ARoomModifiedEvent' => $baseDir . '/lib/Events/ARoomModifiedEvent.php',
    'OCA\\Talk\\Events\\ARoomSyncedEvent' => $baseDir . '/lib/Events/ARoomSyncedEvent.php',
    'OCA\\Talk\\Events\\ASessionLeftRoomEvent' => $baseDir . '/lib/Events/ASessionLeftRoomEvent.php',
    'OCA\\Talk\\Events\\ASystemMessageSentEvent' => $baseDir . '/lib/Events/ASystemMessageSentEvent.php',
    'OCA\\Talk\\Events\\AttendeeRemovedEvent' => $baseDir . '/lib/Events/AttendeeRemovedEvent.php',
    'OCA\\Talk\\Events\\AttendeesAddedEvent' => $baseDir . '/lib/Events/AttendeesAddedEvent.php',
    'OCA\\Talk\\Events\\AttendeesEvent' => $baseDir . '/lib/Events/AttendeesEvent.php',
    'OCA\\Talk\\Events\\AttendeesRemovedEvent' => $baseDir . '/lib/Events/AttendeesRemovedEvent.php',
    'OCA\\Talk\\Events\\BeforeAttendeeRemovedEvent' => $baseDir . '/lib/Events/BeforeAttendeeRemovedEvent.php',
    'OCA\\Talk\\Events\\BeforeAttendeesAddedEvent' => $baseDir . '/lib/Events/BeforeAttendeesAddedEvent.php',
    'OCA\\Talk\\Events\\BeforeCallEndedEvent' => $baseDir . '/lib/Events/BeforeCallEndedEvent.php',
    'OCA\\Talk\\Events\\BeforeCallEndedForEveryoneEvent' => $baseDir . '/lib/Events/BeforeCallEndedForEveryoneEvent.php',
    'OCA\\Talk\\Events\\BeforeCallStartedEvent' => $baseDir . '/lib/Events/BeforeCallStartedEvent.php',
    'OCA\\Talk\\Events\\BeforeChatMessageSentEvent' => $baseDir . '/lib/Events/BeforeChatMessageSentEvent.php',
    'OCA\\Talk\\Events\\BeforeDuplicateShareSentEvent' => $baseDir . '/lib/Events/BeforeDuplicateShareSentEvent.php',
    'OCA\\Talk\\Events\\BeforeEmailInvitationSentEvent' => $baseDir . '/lib/Events/BeforeEmailInvitationSentEvent.php',
    'OCA\\Talk\\Events\\BeforeFederatedUserJoinedRoomEvent' => $baseDir . '/lib/Events/BeforeFederatedUserJoinedRoomEvent.php',
    'OCA\\Talk\\Events\\BeforeGuestJoinedRoomEvent' => $baseDir . '/lib/Events/BeforeGuestJoinedRoomEvent.php',
    'OCA\\Talk\\Events\\BeforeGuestsCleanedUpEvent' => $baseDir . '/lib/Events/BeforeGuestsCleanedUpEvent.php',
    'OCA\\Talk\\Events\\BeforeLobbyModifiedEvent' => $baseDir . '/lib/Events/BeforeLobbyModifiedEvent.php',
    'OCA\\Talk\\Events\\BeforeParticipantModifiedEvent' => $baseDir . '/lib/Events/BeforeParticipantModifiedEvent.php',
    'OCA\\Talk\\Events\\BeforeReactionAddedEvent' => $baseDir . '/lib/Events/BeforeReactionAddedEvent.php',
    'OCA\\Talk\\Events\\BeforeReactionRemovedEvent' => $baseDir . '/lib/Events/BeforeReactionRemovedEvent.php',
    'OCA\\Talk\\Events\\BeforeRoomDeletedEvent' => $baseDir . '/lib/Events/BeforeRoomDeletedEvent.php',
    'OCA\\Talk\\Events\\BeforeRoomModifiedEvent' => $baseDir . '/lib/Events/BeforeRoomModifiedEvent.php',
    'OCA\\Talk\\Events\\BeforeRoomSyncedEvent' => $baseDir . '/lib/Events/BeforeRoomSyncedEvent.php',
    'OCA\\Talk\\Events\\BeforeRoomsFetchEvent' => $baseDir . '/lib/Events/BeforeRoomsFetchEvent.php',
    'OCA\\Talk\\Events\\BeforeSessionLeftRoomEvent' => $baseDir . '/lib/Events/BeforeSessionLeftRoomEvent.php',
    'OCA\\Talk\\Events\\BeforeSignalingResponseSentEvent' => $baseDir . '/lib/Events/BeforeSignalingResponseSentEvent.php',
    'OCA\\Talk\\Events\\BeforeSignalingRoomPropertiesSentEvent' => $baseDir . '/lib/Events/BeforeSignalingRoomPropertiesSentEvent.php',
    'OCA\\Talk\\Events\\BeforeSystemMessageSentEvent' => $baseDir . '/lib/Events/BeforeSystemMessageSentEvent.php',
    'OCA\\Talk\\Events\\BeforeTurnServersGetEvent' => $baseDir . '/lib/Events/BeforeTurnServersGetEvent.php',
    'OCA\\Talk\\Events\\BeforeUserJoinedRoomEvent' => $baseDir . '/lib/Events/BeforeUserJoinedRoomEvent.php',
    'OCA\\Talk\\Events\\BotDisabledEvent' => $baseDir . '/lib/Events/BotDisabledEvent.php',
    'OCA\\Talk\\Events\\BotEnabledEvent' => $baseDir . '/lib/Events/BotEnabledEvent.php',
    'OCA\\Talk\\Events\\BotInstallEvent' => $baseDir . '/lib/Events/BotInstallEvent.php',
    'OCA\\Talk\\Events\\BotInvokeEvent' => $baseDir . '/lib/Events/BotInvokeEvent.php',
    'OCA\\Talk\\Events\\BotUninstallEvent' => $baseDir . '/lib/Events/BotUninstallEvent.php',
    'OCA\\Talk\\Events\\CallEndedEvent' => $baseDir . '/lib/Events/CallEndedEvent.php',
    'OCA\\Talk\\Events\\CallEndedForEveryoneEvent' => $baseDir . '/lib/Events/CallEndedForEveryoneEvent.php',
    'OCA\\Talk\\Events\\CallNotificationSendEvent' => $baseDir . '/lib/Events/CallNotificationSendEvent.php',
    'OCA\\Talk\\Events\\CallStartedEvent' => $baseDir . '/lib/Events/CallStartedEvent.php',
    'OCA\\Talk\\Events\\ChatMessageSentEvent' => $baseDir . '/lib/Events/ChatMessageSentEvent.php',
    'OCA\\Talk\\Events\\EmailInvitationSentEvent' => $baseDir . '/lib/Events/EmailInvitationSentEvent.php',
    'OCA\\Talk\\Events\\FederatedUserJoinedRoomEvent' => $baseDir . '/lib/Events/FederatedUserJoinedRoomEvent.php',
    'OCA\\Talk\\Events\\GuestJoinedRoomEvent' => $baseDir . '/lib/Events/GuestJoinedRoomEvent.php',
    'OCA\\Talk\\Events\\GuestsCleanedUpEvent' => $baseDir . '/lib/Events/GuestsCleanedUpEvent.php',
    'OCA\\Talk\\Events\\LobbyModifiedEvent' => $baseDir . '/lib/Events/LobbyModifiedEvent.php',
    'OCA\\Talk\\Events\\MessageParseEvent' => $baseDir . '/lib/Events/MessageParseEvent.php',
    'OCA\\Talk\\Events\\OverwritePublicSharePropertiesEvent' => $baseDir . '/lib/Events/OverwritePublicSharePropertiesEvent.php',
    'OCA\\Talk\\Events\\ParticipantModifiedEvent' => $baseDir . '/lib/Events/ParticipantModifiedEvent.php',
    'OCA\\Talk\\Events\\ReactionAddedEvent' => $baseDir . '/lib/Events/ReactionAddedEvent.php',
    'OCA\\Talk\\Events\\ReactionRemovedEvent' => $baseDir . '/lib/Events/ReactionRemovedEvent.php',
    'OCA\\Talk\\Events\\RoomCreatedEvent' => $baseDir . '/lib/Events/RoomCreatedEvent.php',
    'OCA\\Talk\\Events\\RoomDeletedEvent' => $baseDir . '/lib/Events/RoomDeletedEvent.php',
    'OCA\\Talk\\Events\\RoomExtendedEvent' => $baseDir . '/lib/Events/RoomExtendedEvent.php',
    'OCA\\Talk\\Events\\RoomModifiedEvent' => $baseDir . '/lib/Events/RoomModifiedEvent.php',
    'OCA\\Talk\\Events\\RoomPasswordVerifyEvent' => $baseDir . '/lib/Events/RoomPasswordVerifyEvent.php',
    'OCA\\Talk\\Events\\RoomSyncedEvent' => $baseDir . '/lib/Events/RoomSyncedEvent.php',
    'OCA\\Talk\\Events\\SessionLeftRoomEvent' => $baseDir . '/lib/Events/SessionLeftRoomEvent.php',
    'OCA\\Talk\\Events\\SystemMessageSentEvent' => $baseDir . '/lib/Events/SystemMessageSentEvent.php',
    'OCA\\Talk\\Events\\SystemMessagesMultipleSentEvent' => $baseDir . '/lib/Events/SystemMessagesMultipleSentEvent.php',
    'OCA\\Talk\\Events\\UserJoinedRoomEvent' => $baseDir . '/lib/Events/UserJoinedRoomEvent.php',
    'OCA\\Talk\\Exceptions\\CannotReachRemoteException' => $baseDir . '/lib/Exceptions/CannotReachRemoteException.php',
    'OCA\\Talk\\Exceptions\\ChatSummaryException' => $baseDir . '/lib/Exceptions/ChatSummaryException.php',
    'OCA\\Talk\\Exceptions\\DialOutFailedException' => $baseDir . '/lib/Exceptions/DialOutFailedException.php',
    'OCA\\Talk\\Exceptions\\FederationRestrictionException' => $baseDir . '/lib/Exceptions/FederationRestrictionException.php',
    'OCA\\Talk\\Exceptions\\ForbiddenException' => $baseDir . '/lib/Exceptions/ForbiddenException.php',
    'OCA\\Talk\\Exceptions\\GuestImportException' => $baseDir . '/lib/Exceptions/GuestImportException.php',
    'OCA\\Talk\\Exceptions\\HostedSignalingServerAPIException' => $baseDir . '/lib/Exceptions/HostedSignalingServerAPIException.php',
    'OCA\\Talk\\Exceptions\\HostedSignalingServerInputException' => $baseDir . '/lib/Exceptions/HostedSignalingServerInputException.php',
    'OCA\\Talk\\Exceptions\\ImpossibleToKillException' => $baseDir . '/lib/Exceptions/ImpossibleToKillException.php',
    'OCA\\Talk\\Exceptions\\InvalidPasswordException' => $baseDir . '/lib/Exceptions/InvalidPasswordException.php',
    'OCA\\Talk\\Exceptions\\InvalidRoomException' => $baseDir . '/lib/Exceptions/InvalidRoomException.php',
    'OCA\\Talk\\Exceptions\\InvalidTagNameException' => $baseDir . '/lib/Exceptions/InvalidTagNameException.php',
    'OCA\\Talk\\Exceptions\\LiveTranscriptionAppAPIException' => $baseDir . '/lib/Exceptions/LiveTranscriptionAppAPIException.php',
    'OCA\\Talk\\Exceptions\\LiveTranscriptionAppNotEnabledException' => $baseDir . '/lib/Exceptions/LiveTranscriptionAppNotEnabledException.php',
    'OCA\\Talk\\Exceptions\\LiveTranscriptionAppResponseException' => $baseDir . '/lib/Exceptions/LiveTranscriptionAppResponseException.php',
    'OCA\\Talk\\Exceptions\\LiveTranslationNotSupportedException' => $baseDir . '/lib/Exceptions/LiveTranslationNotSupportedException.php',
    'OCA\\Talk\\Exceptions\\MessagingNotAllowedException' => $baseDir . '/lib/Exceptions/MessagingNotAllowedException.php',
    'OCA\\Talk\\Exceptions\\ParticipantNotFoundException' => $baseDir . '/lib/Exceptions/ParticipantNotFoundException.php',
    'OCA\\Talk\\Exceptions\\ParticipantProperty\\PermissionsException' => $baseDir . '/lib/Exceptions/ParticipantProperty/PermissionsException.php',
    'OCA\\Talk\\Exceptions\\PermissionsException' => $baseDir . '/lib/Exceptions/PermissionsException.php',
    'OCA\\Talk\\Exceptions\\PollPropertyException' => $baseDir . '/lib/Exceptions/PollPropertyException.php',
    'OCA\\Talk\\Exceptions\\ReactionAlreadyExistsException' => $baseDir . '/lib/Exceptions/ReactionAlreadyExistsException.php',
    'OCA\\Talk\\Exceptions\\ReactionNotSupportedException' => $baseDir . '/lib/Exceptions/ReactionNotSupportedException.php',
    'OCA\\Talk\\Exceptions\\ReactionOutOfContextException' => $baseDir . '/lib/Exceptions/ReactionOutOfContextException.php',
    'OCA\\Talk\\Exceptions\\RecordingNotFoundException' => $baseDir . '/lib/Exceptions/RecordingNotFoundException.php',
    'OCA\\Talk\\Exceptions\\RemoteClientException' => $baseDir . '/lib/Exceptions/RemoteClientException.php',
    'OCA\\Talk\\Exceptions\\RoomHasNoModeratorException' => $baseDir . '/lib/Exceptions/RoomHasNoModeratorException.php',
    'OCA\\Talk\\Exceptions\\RoomNotFoundException' => $baseDir . '/lib/Exceptions/RoomNotFoundException.php',
    'OCA\\Talk\\Exceptions\\RoomProperty\\AvatarException' => $baseDir . '/lib/Exceptions/RoomProperty/AvatarException.php',
    'OCA\\Talk\\Exceptions\\RoomProperty\\BreakoutRoomModeException' => $baseDir . '/lib/Exceptions/RoomProperty/BreakoutRoomModeException.php',
    'OCA\\Talk\\Exceptions\\RoomProperty\\BreakoutRoomStatusException' => $baseDir . '/lib/Exceptions/RoomProperty/BreakoutRoomStatusException.php',
    'OCA\\Talk\\Exceptions\\RoomProperty\\CallRecordingException' => $baseDir . '/lib/Exceptions/RoomProperty/CallRecordingException.php',
    'OCA\\Talk\\Exceptions\\RoomProperty\\CreationException' => $baseDir . '/lib/Exceptions/RoomProperty/CreationException.php',
    'OCA\\Talk\\Exceptions\\RoomProperty\\DefaultPermissionsException' => $baseDir . '/lib/Exceptions/RoomProperty/DefaultPermissionsException.php',
    'OCA\\Talk\\Exceptions\\RoomProperty\\DescriptionException' => $baseDir . '/lib/Exceptions/RoomProperty/DescriptionException.php',
    'OCA\\Talk\\Exceptions\\RoomProperty\\ListableException' => $baseDir . '/lib/Exceptions/RoomProperty/ListableException.php',
    'OCA\\Talk\\Exceptions\\RoomProperty\\LobbyException' => $baseDir . '/lib/Exceptions/RoomProperty/LobbyException.php',
    'OCA\\Talk\\Exceptions\\RoomProperty\\MentionPermissionsException' => $baseDir . '/lib/Exceptions/RoomProperty/MentionPermissionsException.php',
    'OCA\\Talk\\Exceptions\\RoomProperty\\MessageExpirationException' => $baseDir . '/lib/Exceptions/RoomProperty/MessageExpirationException.php',
    'OCA\\Talk\\Exceptions\\RoomProperty\\NameException' => $baseDir . '/lib/Exceptions/RoomProperty/NameException.php',
    'OCA\\Talk\\Exceptions\\RoomProperty\\PasswordException' => $baseDir . '/lib/Exceptions/RoomProperty/PasswordException.php',
    'OCA\\Talk\\Exceptions\\RoomProperty\\ReadOnlyException' => $baseDir . '/lib/Exceptions/RoomProperty/ReadOnlyException.php',
    'OCA\\Talk\\Exceptions\\RoomProperty\\RecordingConsentException' => $baseDir . '/lib/Exceptions/RoomProperty/RecordingConsentException.php',
    'OCA\\Talk\\Exceptions\\RoomProperty\\SipConfigurationException' => $baseDir . '/lib/Exceptions/RoomProperty/SipConfigurationException.php',
    'OCA\\Talk\\Exceptions\\RoomProperty\\TypeException' => $baseDir . '/lib/Exceptions/RoomProperty/TypeException.php',
    'OCA\\Talk\\Exceptions\\TagLimitExceededException' => $baseDir . '/lib/Exceptions/TagLimitExceededException.php',
    'OCA\\Talk\\Exceptions\\TagNameAlreadyInUseException' => $baseDir . '/lib/Exceptions/TagNameAlreadyInUseException.php',
    'OCA\\Talk\\Exceptions\\TagNotCustomException' => $baseDir . '/lib/Exceptions/TagNotCustomException.php',
    'OCA\\Talk\\Exceptions\\UnauthorizedException' => $baseDir . '/lib/Exceptions/UnauthorizedException.php',
    'OCA\\Talk\\Exceptions\\WrongPermissionsException' => $baseDir . '/lib/Exceptions/WrongPermissionsException.php',
    'OCA\\Talk\\Federation\\BackendNotifier' => $baseDir . '/lib/Federation/BackendNotifier.php',
    'OCA\\Talk\\Federation\\CloudFederationProviderTalk' => $baseDir . '/lib/Federation/CloudFederationProviderTalk.php',
    'OCA\\Talk\\Federation\\FederationManager' => $baseDir . '/lib/Federation/FederationManager.php',
    'OCA\\Talk\\Federation\\Proxy\\TalkV1\\Controller\\AvatarController' => $baseDir . '/lib/Federation/Proxy/TalkV1/Controller/AvatarController.php',
    'OCA\\Talk\\Federation\\Proxy\\TalkV1\\Controller\\CallController' => $baseDir . '/lib/Federation/Proxy/TalkV1/Controller/CallController.php',
    'OCA\\Talk\\Federation\\Proxy\\TalkV1\\Controller\\ChatController' => $baseDir . '/lib/Federation/Proxy/TalkV1/Controller/ChatController.php',
    'OCA\\Talk\\Federation\\Proxy\\TalkV1\\Controller\\PollController' => $baseDir . '/lib/Federation/Proxy/TalkV1/Controller/PollController.php',
    'OCA\\Talk\\Federation\\Proxy\\TalkV1\\Controller\\ReactionController' => $baseDir . '/lib/Federation/Proxy/TalkV1/Controller/ReactionController.php',
    'OCA\\Talk\\Federation\\Proxy\\TalkV1\\Controller\\RoomController' => $baseDir . '/lib/Federation/Proxy/TalkV1/Controller/RoomController.php',
    'OCA\\Talk\\Federation\\Proxy\\TalkV1\\Controller\\SignalingController' => $baseDir . '/lib/Federation/Proxy/TalkV1/Controller/SignalingController.php',
    'OCA\\Talk\\Federation\\Proxy\\TalkV1\\Controller\\ThreadController' => $baseDir . '/lib/Federation/Proxy/TalkV1/Controller/ThreadController.php',
    'OCA\\Talk\\Federation\\Proxy\\TalkV1\\Listener\\ResourceTypeRegisterListener' => $baseDir . '/lib/Federation/Proxy/TalkV1/Listener/ResourceTypeRegisterListener.php',
    'OCA\\Talk\\Federation\\Proxy\\TalkV1\\Notifier\\BeforeRoomDeletedListener' => $baseDir . '/lib/Federation/Proxy/TalkV1/Notifier/BeforeRoomDeletedListener.php',
    'OCA\\Talk\\Federation\\Proxy\\TalkV1\\Notifier\\CancelRetryOCMListener' => $baseDir . '/lib/Federation/Proxy/TalkV1/Notifier/CancelRetryOCMListener.php',
    'OCA\\Talk\\Federation\\Proxy\\TalkV1\\Notifier\\MessageSentListener' => $baseDir . '/lib/Federation/Proxy/TalkV1/Notifier/MessageSentListener.php',
    'OCA\\Talk\\Federation\\Proxy\\TalkV1\\Notifier\\ParticipantModifiedListener' => $baseDir . '/lib/Federation/Proxy/TalkV1/Notifier/ParticipantModifiedListener.php',
    'OCA\\Talk\\Federation\\Proxy\\TalkV1\\Notifier\\RoomModifiedListener' => $baseDir . '/lib/Federation/Proxy/TalkV1/Notifier/RoomModifiedListener.php',
    'OCA\\Talk\\Federation\\Proxy\\TalkV1\\ProxyRequest' => $baseDir . '/lib/Federation/Proxy/TalkV1/ProxyRequest.php',
    'OCA\\Talk\\Federation\\Proxy\\TalkV1\\UserConverter' => $baseDir . '/lib/Federation/Proxy/TalkV1/UserConverter.php',
    'OCA\\Talk\\Federation\\RestrictionValidator' => $baseDir . '/lib/Federation/RestrictionValidator.php',
    'OCA\\Talk\\Files\\Listener' => $baseDir . '/lib/Files/Listener.php',
    'OCA\\Talk\\Files\\TemplateLoader' => $baseDir . '/lib/Files/TemplateLoader.php',
    'OCA\\Talk\\Files\\Util' => $baseDir . '/lib/Files/Util.php',
    'OCA\\Talk\\FloatingCall\\FloatingCallPluginLoader' => $baseDir . '/lib/FloatingCall/FloatingCallPluginLoader.php',
    'OCA\\Talk\\Flow\\Operation' => $baseDir . '/lib/Flow/Operation.php',
    'OCA\\Talk\\Flow\\RegisterOperationsListener' => $baseDir . '/lib/Flow/RegisterOperationsListener.php',
    'OCA\\Talk\\GuestManager' => $baseDir . '/lib/GuestManager.php',
    'OCA\\Talk\\Listener\\AMembershipListener' => $baseDir . '/lib/Listener/AMembershipListener.php',
    'OCA\\Talk\\Listener\\AddMissingIndicesListener' => $baseDir . '/lib/Listener/AddMissingIndicesListener.php',
    'OCA\\Talk\\Listener\\BeforeUserLoggedOutListener' => $baseDir . '/lib/Listener/BeforeUserLoggedOutListener.php',
    'OCA\\Talk\\Listener\\BotListener' => $baseDir . '/lib/Listener/BotListener.php',
    'OCA\\Talk\\Listener\\CSPListener' => $baseDir . '/lib/Listener/CSPListener.php',
    'OCA\\Talk\\Listener\\CalDavEventListener' => $baseDir . '/lib/Listener/CalDavEventListener.php',
    'OCA\\Talk\\Listener\\CircleDeletedListener' => $baseDir . '/lib/Listener/CircleDeletedListener.php',
    'OCA\\Talk\\Listener\\CircleEditedListener' => $baseDir . '/lib/Listener/CircleEditedListener.php',
    'OCA\\Talk\\Listener\\CircleMembershipListener' => $baseDir . '/lib/Listener/CircleMembershipListener.php',
    'OCA\\Talk\\Listener\\DisplayNameListener' => $baseDir . '/lib/Listener/DisplayNameListener.php',
    'OCA\\Talk\\Listener\\FeaturePolicyListener' => $baseDir . '/lib/Listener/FeaturePolicyListener.php',
    'OCA\\Talk\\Listener\\GroupDeletedListener' => $baseDir . '/lib/Listener/GroupDeletedListener.php',
    'OCA\\Talk\\Listener\\GroupMembershipListener' => $baseDir . '/lib/Listener/GroupMembershipListener.php',
    'OCA\\Talk\\Listener\\NoteToSelfListener' => $baseDir . '/lib/Listener/NoteToSelfListener.php',
    'OCA\\Talk\\Listener\\RestrictStartingCalls' => $baseDir . '/lib/Listener/RestrictStartingCalls.php',
    'OCA\\Talk\\Listener\\SampleConversationsListener' => $baseDir . '/lib/Listener/SampleConversationsListener.php',
    'OCA\\Talk\\Listener\\ThreadListener' => $baseDir . '/lib/Listener/ThreadListener.php',
    'OCA\\Talk\\Listener\\UserDeletedListener' => $baseDir . '/lib/Listener/UserDeletedListener.php',
    'OCA\\Talk\\Manager' => $baseDir . '/lib/Manager.php',
    'OCA\\Talk\\Maps\\MapsPluginLoader' => $baseDir . '/lib/Maps/MapsPluginLoader.php',
    'OCA\\Talk\\MatterbridgeManager' => $baseDir . '/lib/MatterbridgeManager.php',
    'OCA\\Talk\\Middleware\\Attribute\\AllowWithoutParticipantWhenPendingInvitation' => $baseDir . '/lib/Middleware/Attribute/AllowWithoutParticipantWhenPendingInvitation.php',
    'OCA\\Talk\\Middleware\\Attribute\\FederationSupported' => $baseDir . '/lib/Middleware/Attribute/FederationSupported.php',
    'OCA\\Talk\\Middleware\\Attribute\\RequireAuthenticatedParticipant' => $baseDir . '/lib/Middleware/Attribute/RequireAuthenticatedParticipant.php',
    'OCA\\Talk\\Middleware\\Attribute\\RequireCallEnabled' => $baseDir . '/lib/Middleware/Attribute/RequireCallEnabled.php',
    'OCA\\Talk\\Middleware\\Attribute\\RequireFederatedParticipant' => $baseDir . '/lib/Middleware/Attribute/RequireFederatedParticipant.php',
    'OCA\\Talk\\Middleware\\Attribute\\RequireLoggedInModeratorParticipant' => $baseDir . '/lib/Middleware/Attribute/RequireLoggedInModeratorParticipant.php',
    'OCA\\Talk\\Middleware\\Attribute\\RequireLoggedInParticipant' => $baseDir . '/lib/Middleware/Attribute/RequireLoggedInParticipant.php',
    'OCA\\Talk\\Middleware\\Attribute\\RequireModeratorOrNoLobby' => $baseDir . '/lib/Middleware/Attribute/RequireModeratorOrNoLobby.php',
    'OCA\\Talk\\Middleware\\Attribute\\RequireModeratorParticipant' => $baseDir . '/lib/Middleware/Attribute/RequireModeratorParticipant.php',
    'OCA\\Talk\\Middleware\\Attribute\\RequireParticipant' => $baseDir . '/lib/Middleware/Attribute/RequireParticipant.php',
    'OCA\\Talk\\Middleware\\Attribute\\RequireParticipantOrLoggedInAndListedConversation' => $baseDir . '/lib/Middleware/Attribute/RequireParticipantOrLoggedInAndListedConversation.php',
    'OCA\\Talk\\Middleware\\Attribute\\RequirePermission' => $baseDir . '/lib/Middleware/Attribute/RequirePermission.php',
    'OCA\\Talk\\Middleware\\Attribute\\RequireReadWriteConversation' => $baseDir . '/lib/Middleware/Attribute/RequireReadWriteConversation.php',
    'OCA\\Talk\\Middleware\\Attribute\\RequireRoom' => $baseDir . '/lib/Middleware/Attribute/RequireRoom.php',
    'OCA\\Talk\\Middleware\\CanUseTalkMiddleware' => $baseDir . '/lib/Middleware/CanUseTalkMiddleware.php',
    'OCA\\Talk\\Middleware\\Exceptions\\CanNotUseTalkException' => $baseDir . '/lib/Middleware/Exceptions/CanNotUseTalkException.php',
    'OCA\\Talk\\Middleware\\Exceptions\\FederationUnsupportedFeatureException' => $baseDir . '/lib/Middleware/Exceptions/FederationUnsupportedFeatureException.php',
    'OCA\\Talk\\Middleware\\Exceptions\\LobbyException' => $baseDir . '/lib/Middleware/Exceptions/LobbyException.php',
    'OCA\\Talk\\Middleware\\Exceptions\\NotAModeratorException' => $baseDir . '/lib/Middleware/Exceptions/NotAModeratorException.php',
    'OCA\\Talk\\Middleware\\Exceptions\\ReadOnlyException' => $baseDir . '/lib/Middleware/Exceptions/ReadOnlyException.php',
    'OCA\\Talk\\Middleware\\Exceptions\\UnsupportedClientVersionException' => $baseDir . '/lib/Middleware/Exceptions/UnsupportedClientVersionException.php',
    'OCA\\Talk\\Middleware\\InjectionMiddleware' => $baseDir . '/lib/Middleware/InjectionMiddleware.php',
    'OCA\\Talk\\Middleware\\ParameterOutOfRangeMiddleware' => $baseDir . '/lib/Middleware/ParameterOutOfRangeMiddleware.php',
    'OCA\\Talk\\Migration\\CacheUserDisplayNames' => $baseDir . '/lib/Migration/CacheUserDisplayNames.php',
    'OCA\\Talk\\Migration\\ClearResourceAccessCache' => $baseDir . '/lib/Migration/ClearResourceAccessCache.php',
    'OCA\\Talk\\Migration\\FixLastReadMessageZero' => $baseDir . '/lib/Migration/FixLastReadMessageZero.php',
    'OCA\\Talk\\Migration\\FixNamespaceInDatabaseTables' => $baseDir . '/lib/Migration/FixNamespaceInDatabaseTables.php',
    'OCA\\Talk\\Migration\\RegenerateSignalingKeys' => $baseDir . '/lib/Migration/RegenerateSignalingKeys.php',
    'OCA\\Talk\\Migration\\Version10000Date20200819121721' => $baseDir . '/lib/Migration/Version10000Date20200819121721.php',
    'OCA\\Talk\\Migration\\Version10000Date20201012144235' => $baseDir . '/lib/Migration/Version10000Date20201012144235.php',
    'OCA\\Talk\\Migration\\Version10000Date20201015134000' => $baseDir . '/lib/Migration/Version10000Date20201015134000.php',
    'OCA\\Talk\\Migration\\Version10000Date20201015143852' => $baseDir . '/lib/Migration/Version10000Date20201015143852.php',
    'OCA\\Talk\\Migration\\Version10000Date20201015150000' => $baseDir . '/lib/Migration/Version10000Date20201015150000.php',
    'OCA\\Talk\\Migration\\Version11000Date20200922161218' => $baseDir . '/lib/Migration/Version11000Date20200922161218.php',
    'OCA\\Talk\\Migration\\Version11000Date20201011082810' => $baseDir . '/lib/Migration/Version11000Date20201011082810.php',
    'OCA\\Talk\\Migration\\Version11000Date20201201102528' => $baseDir . '/lib/Migration/Version11000Date20201201102528.php',
    'OCA\\Talk\\Migration\\Version11000Date20201204110210' => $baseDir . '/lib/Migration/Version11000Date20201204110210.php',
    'OCA\\Talk\\Migration\\Version11000Date20201209142525' => $baseDir . '/lib/Migration/Version11000Date20201209142525.php',
    'OCA\\Talk\\Migration\\Version11000Date20201209142526' => $baseDir . '/lib/Migration/Version11000Date20201209142526.php',
    'OCA\\Talk\\Migration\\Version11001Date20210211111527' => $baseDir . '/lib/Migration/Version11001Date20210211111527.php',
    'OCA\\Talk\\Migration\\Version11001Date20210212105406' => $baseDir . '/lib/Migration/Version11001Date20210212105406.php',
    'OCA\\Talk\\Migration\\Version12000Date20210217134030' => $baseDir . '/lib/Migration/Version12000Date20210217134030.php',
    'OCA\\Talk\\Migration\\Version12000Date20210401124139' => $baseDir . '/lib/Migration/Version12000Date20210401124139.php',
    'OCA\\Talk\\Migration\\Version12000Date20210528100404' => $baseDir . '/lib/Migration/Version12000Date20210528100404.php',
    'OCA\\Talk\\Migration\\Version13000Date20210625232111' => $baseDir . '/lib/Migration/Version13000Date20210625232111.php',
    'OCA\\Talk\\Migration\\Version13000Date20210901164235' => $baseDir . '/lib/Migration/Version13000Date20210901164235.php',
    'OCA\\Talk\\Migration\\Version13000Date20210921142733' => $baseDir . '/lib/Migration/Version13000Date20210921142733.php',
    'OCA\\Talk\\Migration\\Version13000Date20211007192733' => $baseDir . '/lib/Migration/Version13000Date20211007192733.php',
    'OCA\\Talk\\Migration\\Version14000Date20211203132513' => $baseDir . '/lib/Migration/Version14000Date20211203132513.php',
    'OCA\\Talk\\Migration\\Version14000Date20220217115327' => $baseDir . '/lib/Migration/Version14000Date20220217115327.php',
    'OCA\\Talk\\Migration\\Version14000Date20220328153054' => $baseDir . '/lib/Migration/Version14000Date20220328153054.php',
    'OCA\\Talk\\Migration\\Version14000Date20220330141647' => $baseDir . '/lib/Migration/Version14000Date20220330141647.php',
    'OCA\\Talk\\Migration\\Version15000Date20220427183026' => $baseDir . '/lib/Migration/Version15000Date20220427183026.php',
    'OCA\\Talk\\Migration\\Version15000Date20220503121308' => $baseDir . '/lib/Migration/Version15000Date20220503121308.php',
    'OCA\\Talk\\Migration\\Version15000Date20220506005058' => $baseDir . '/lib/Migration/Version15000Date20220506005058.php',
    'OCA\\Talk\\Migration\\Version16000Date20221110151714' => $baseDir . '/lib/Migration/Version16000Date20221110151714.php',
    'OCA\\Talk\\Migration\\Version16000Date20221116163301' => $baseDir . '/lib/Migration/Version16000Date20221116163301.php',
    'OCA\\Talk\\Migration\\Version16000Date20221208013745' => $baseDir . '/lib/Migration/Version16000Date20221208013745.php',
    'OCA\\Talk\\Migration\\Version16000Date20230502145340' => $baseDir . '/lib/Migration/Version16000Date20230502145340.php',
    'OCA\\Talk\\Migration\\Version18000Date20230504205823' => $baseDir . '/lib/Migration/Version18000Date20230504205823.php',
    'OCA\\Talk\\Migration\\Version18000Date20230808120823' => $baseDir . '/lib/Migration/Version18000Date20230808120823.php',
    'OCA\\Talk\\Migration\\Version18000Date20230821112014' => $baseDir . '/lib/Migration/Version18000Date20230821112014.php',
    'OCA\\Talk\\Migration\\Version18000Date20230824123939' => $baseDir . '/lib/Migration/Version18000Date20230824123939.php',
    'OCA\\Talk\\Migration\\Version18000Date20230920182747' => $baseDir . '/lib/Migration/Version18000Date20230920182747.php',
    'OCA\\Talk\\Migration\\Version18000Date20230928131717' => $baseDir . '/lib/Migration/Version18000Date20230928131717.php',
    'OCA\\Talk\\Migration\\Version18000Date20231005091416' => $baseDir . '/lib/Migration/Version18000Date20231005091416.php',
    'OCA\\Talk\\Migration\\Version18000Date20231018065816' => $baseDir . '/lib/Migration/Version18000Date20231018065816.php',
    'OCA\\Talk\\Migration\\Version18000Date20231024141626' => $baseDir . '/lib/Migration/Version18000Date20231024141626.php',
    'OCA\\Talk\\Migration\\Version18000Date20231024141627' => $baseDir . '/lib/Migration/Version18000Date20231024141627.php',
    'OCA\\Talk\\Migration\\Version19000Date20240212155937' => $baseDir . '/lib/Migration/Version19000Date20240212155937.php',
    'OCA\\Talk\\Migration\\Version19000Date20240214095011' => $baseDir . '/lib/Migration/Version19000Date20240214095011.php',
    'OCA\\Talk\\Migration\\Version19000Date20240227084313' => $baseDir . '/lib/Migration/Version19000Date20240227084313.php',
    'OCA\\Talk\\Migration\\Version19000Date20240305115243' => $baseDir . '/lib/Migration/Version19000Date20240305115243.php',
    'OCA\\Talk\\Migration\\Version19000Date20240312105627' => $baseDir . '/lib/Migration/Version19000Date20240312105627.php',
    'OCA\\Talk\\Migration\\Version19000Date20240313134926' => $baseDir . '/lib/Migration/Version19000Date20240313134926.php',
    'OCA\\Talk\\Migration\\Version19000Date20240416104656' => $baseDir . '/lib/Migration/Version19000Date20240416104656.php',
    'OCA\\Talk\\Migration\\Version19000Date20240709183938' => $baseDir . '/lib/Migration/Version19000Date20240709183938.php',
    'OCA\\Talk\\Migration\\Version20000Date20240621150333' => $baseDir . '/lib/Migration/Version20000Date20240621150333.php',
    'OCA\\Talk\\Migration\\Version20000Date20240621150334' => $baseDir . '/lib/Migration/Version20000Date20240621150334.php',
    'OCA\\Talk\\Migration\\Version20000Date20240621150335' => $baseDir . '/lib/Migration/Version20000Date20240621150335.php',
    'OCA\\Talk\\Migration\\Version20000Date20240623123938' => $baseDir . '/lib/Migration/Version20000Date20240623123938.php',
    'OCA\\Talk\\Migration\\Version20000Date20240716190335' => $baseDir . '/lib/Migration/Version20000Date20240716190335.php',
    'OCA\\Talk\\Migration\\Version20000Date20240717180417' => $baseDir . '/lib/Migration/Version20000Date20240717180417.php',
    'OCA\\Talk\\Migration\\Version20000Date20240718031959' => $baseDir . '/lib/Migration/Version20000Date20240718031959.php',
    'OCA\\Talk\\Migration\\Version2000Date20170707093535' => $baseDir . '/lib/Migration/Version2000Date20170707093535.php',
    'OCA\\Talk\\Migration\\Version2000Date20171026140256' => $baseDir . '/lib/Migration/Version2000Date20171026140256.php',
    'OCA\\Talk\\Migration\\Version2000Date20171026140257' => $baseDir . '/lib/Migration/Version2000Date20171026140257.php',
    'OCA\\Talk\\Migration\\Version2001Date20170707115443' => $baseDir . '/lib/Migration/Version2001Date20170707115443.php',
    'OCA\\Talk\\Migration\\Version2001Date20170913104501' => $baseDir . '/lib/Migration/Version2001Date20170913104501.php',
    'OCA\\Talk\\Migration\\Version2001Date20170921145301' => $baseDir . '/lib/Migration/Version2001Date20170921145301.php',
    'OCA\\Talk\\Migration\\Version2001Date20170929092606' => $baseDir . '/lib/Migration/Version2001Date20170929092606.php',
    'OCA\\Talk\\Migration\\Version2001Date20171009132424' => $baseDir . '/lib/Migration/Version2001Date20171009132424.php',
    'OCA\\Talk\\Migration\\Version2001Date20171026134605' => $baseDir . '/lib/Migration/Version2001Date20171026134605.php',
    'OCA\\Talk\\Migration\\Version2001Date20171026141336' => $baseDir . '/lib/Migration/Version2001Date20171026141336.php',
    'OCA\\Talk\\Migration\\Version2001Date20171031102049' => $baseDir . '/lib/Migration/Version2001Date20171031102049.php',
    'OCA\\Talk\\Migration\\Version2001Date20180103144447' => $baseDir . '/lib/Migration/Version2001Date20180103144447.php',
    'OCA\\Talk\\Migration\\Version2001Date20180103150836' => $baseDir . '/lib/Migration/Version2001Date20180103150836.php',
    'OCA\\Talk\\Migration\\Version21000Date20240919222538' => $baseDir . '/lib/Migration/Version21000Date20240919222538.php',
    'OCA\\Talk\\Migration\\Version21001Date20250328123156' => $baseDir . '/lib/Migration/Version21001Date20250328123156.php',
    'OCA\\Talk\\Migration\\Version21001Date20250417141337' => $baseDir . '/lib/Migration/Version21001Date20250417141337.php',
    'OCA\\Talk\\Migration\\Version21001Date20250509153510' => $baseDir . '/lib/Migration/Version21001Date20250509153510.php',
    'OCA\\Talk\\Migration\\Version22000Date20250526102909' => $baseDir . '/lib/Migration/Version22000Date20250526102909.php',
    'OCA\\Talk\\Migration\\Version22000Date20250623142327' => $baseDir . '/lib/Migration/Version22000Date20250623142327.php',
    'OCA\\Talk\\Migration\\Version22000Date20250710124258' => $baseDir . '/lib/Migration/Version22000Date20250710124258.php',
    'OCA\\Talk\\Migration\\Version22000Date20250803160923' => $baseDir . '/lib/Migration/Version22000Date20250803160923.php',
    'OCA\\Talk\\Migration\\Version22000Date20250813122342' => $baseDir . '/lib/Migration/Version22000Date20250813122342.php',
    'OCA\\Talk\\Migration\\Version22001Date20250927174738' => $baseDir . '/lib/Migration/Version22001Date20250927174738.php',
    'OCA\\Talk\\Migration\\Version23000Date20251030090219' => $baseDir . '/lib/Migration/Version23000Date20251030090219.php',
    'OCA\\Talk\\Migration\\Version23000Date20251105125333' => $baseDir . '/lib/Migration/Version23000Date20251105125333.php',
    'OCA\\Talk\\Migration\\Version23000Date20251114105144' => $baseDir . '/lib/Migration/Version23000Date20251114105144.php',
    'OCA\\Talk\\Migration\\Version23000Date20251215204457' => $baseDir . '/lib/Migration/Version23000Date20251215204457.php',
    'OCA\\Talk\\Migration\\Version23000Date20251218142903' => $baseDir . '/lib/Migration/Version23000Date20251218142903.php',
    'OCA\\Talk\\Migration\\Version23000Date20260107162758' => $baseDir . '/lib/Migration/Version23000Date20260107162758.php',
    'OCA\\Talk\\Migration\\Version23000Date20260123100000' => $baseDir . '/lib/Migration/Version23000Date20260123100000.php',
    'OCA\\Talk\\Migration\\Version24000Date20260219090000' => $baseDir . '/lib/Migration/Version24000Date20260219090000.php',
    'OCA\\Talk\\Migration\\Version24000Date20260313120000' => $baseDir . '/lib/Migration/Version24000Date20260313120000.php',
    'OCA\\Talk\\Migration\\Version3002Date20180319104030' => $baseDir . '/lib/Migration/Version3002Date20180319104030.php',
    'OCA\\Talk\\Migration\\Version3003Date20180707222130' => $baseDir . '/lib/Migration/Version3003Date20180707222130.php',
    'OCA\\Talk\\Migration\\Version3003Date20180718112436' => $baseDir . '/lib/Migration/Version3003Date20180718112436.php',
    'OCA\\Talk\\Migration\\Version3003Date20180718133519' => $baseDir . '/lib/Migration/Version3003Date20180718133519.php',
    'OCA\\Talk\\Migration\\Version3003Date20180720162342' => $baseDir . '/lib/Migration/Version3003Date20180720162342.php',
    'OCA\\Talk\\Migration\\Version3003Date20180722152733' => $baseDir . '/lib/Migration/Version3003Date20180722152733.php',
    'OCA\\Talk\\Migration\\Version3003Date20180722152849' => $baseDir . '/lib/Migration/Version3003Date20180722152849.php',
    'OCA\\Talk\\Migration\\Version3003Date20180730080327' => $baseDir . '/lib/Migration/Version3003Date20180730080327.php',
    'OCA\\Talk\\Migration\\Version4099Date20181001123058' => $baseDir . '/lib/Migration/Version4099Date20181001123058.php',
    'OCA\\Talk\\Migration\\Version5099Date20190121102337' => $baseDir . '/lib/Migration/Version5099Date20190121102337.php',
    'OCA\\Talk\\Migration\\Version5099Date20190319134820' => $baseDir . '/lib/Migration/Version5099Date20190319134820.php',
    'OCA\\Talk\\Migration\\Version6099Date20190627172429' => $baseDir . '/lib/Migration/Version6099Date20190627172429.php',
    'OCA\\Talk\\Migration\\Version7000Date20190717141457' => $baseDir . '/lib/Migration/Version7000Date20190717141457.php',
    'OCA\\Talk\\Migration\\Version7000Date20190724121136' => $baseDir . '/lib/Migration/Version7000Date20190724121136.php',
    'OCA\\Talk\\Migration\\Version7000Date20190724121137' => $baseDir . '/lib/Migration/Version7000Date20190724121137.php',
    'OCA\\Talk\\Migration\\Version8000Date20200331144101' => $baseDir . '/lib/Migration/Version8000Date20200331144101.php',
    'OCA\\Talk\\Migration\\Version8000Date20200402124456' => $baseDir . '/lib/Migration/Version8000Date20200402124456.php',
    'OCA\\Talk\\Migration\\Version8000Date20200407073807' => $baseDir . '/lib/Migration/Version8000Date20200407073807.php',
    'OCA\\Talk\\Migration\\Version8000Date20200407115318' => $baseDir . '/lib/Migration/Version8000Date20200407115318.php',
    'OCA\\Talk\\Model\\Attachment' => $baseDir . '/lib/Model/Attachment.php',
    'OCA\\Talk\\Model\\AttachmentMapper' => $baseDir . '/lib/Model/AttachmentMapper.php',
    'OCA\\Talk\\Model\\Attendee' => $baseDir . '/lib/Model/Attendee.php',
    'OCA\\Talk\\Model\\AttendeeMapper' => $baseDir . '/lib/Model/AttendeeMapper.php',
    'OCA\\Talk\\Model\\Ban' => $baseDir . '/lib/Model/Ban.php',
    'OCA\\Talk\\Model\\BanMapper' => $baseDir . '/lib/Model/BanMapper.php',
    'OCA\\Talk\\Model\\Bot' => $baseDir . '/lib/Model/Bot.php',
    'OCA\\Talk\\Model\\BotConversation' => $baseDir . '/lib/Model/BotConversation.php',
    'OCA\\Talk\\Model\\BotConversationMapper' => $baseDir . '/lib/Model/BotConversationMapper.php',
    'OCA\\Talk\\Model\\BotServer' => $baseDir . '/lib/Model/BotServer.php',
    'OCA\\Talk\\Model\\BotServerMapper' => $baseDir . '/lib/Model/BotServerMapper.php',
    'OCA\\Talk\\Model\\BreakoutRoom' => $baseDir . '/lib/Model/BreakoutRoom.php',
    'OCA\\Talk\\Model\\Consent' => $baseDir . '/lib/Model/Consent.php',
    'OCA\\Talk\\Model\\ConsentMapper' => $baseDir . '/lib/Model/ConsentMapper.php',
    'OCA\\Talk\\Model\\ConversationTag' => $baseDir . '/lib/Model/ConversationTag.php',
    'OCA\\Talk\\Model\\ConversationTagMapper' => $baseDir . '/lib/Model/ConversationTagMapper.php',
    'OCA\\Talk\\Model\\Invitation' => $baseDir . '/lib/Model/Invitation.php',
    'OCA\\Talk\\Model\\InvitationList' => $baseDir . '/lib/Model/InvitationList.php',
    'OCA\\Talk\\Model\\InvitationMapper' => $baseDir . '/lib/Model/InvitationMapper.php',
    'OCA\\Talk\\Model\\Message' => $baseDir . '/lib/Model/Message.php',
    'OCA\\Talk\\Model\\PhoneNumber' => $baseDir . '/lib/Model/PhoneNumber.php',
    'OCA\\Talk\\Model\\PhoneNumberMapper' => $baseDir . '/lib/Model/PhoneNumberMapper.php',
    'OCA\\Talk\\Model\\Poll' => $baseDir . '/lib/Model/Poll.php',
    'OCA\\Talk\\Model\\PollMapper' => $baseDir . '/lib/Model/PollMapper.php',
    'OCA\\Talk\\Model\\ProxyCacheMessage' => $baseDir . '/lib/Model/ProxyCacheMessage.php',
    'OCA\\Talk\\Model\\ProxyCacheMessageMapper' => $baseDir . '/lib/Model/ProxyCacheMessageMapper.php',
    'OCA\\Talk\\Model\\Reminder' => $baseDir . '/lib/Model/Reminder.php',
    'OCA\\Talk\\Model\\ReminderMapper' => $baseDir . '/lib/Model/ReminderMapper.php',
    'OCA\\Talk\\Model\\RetryNotification' => $baseDir . '/lib/Model/RetryNotification.php',
    'OCA\\Talk\\Model\\RetryNotificationMapper' => $baseDir . '/lib/Model/RetryNotificationMapper.php',
    'OCA\\Talk\\Model\\ScheduledMessage' => $baseDir . '/lib/Model/ScheduledMessage.php',
    'OCA\\Talk\\Model\\ScheduledMessageMapper' => $baseDir . '/lib/Model/ScheduledMessageMapper.php',
    'OCA\\Talk\\Model\\SelectHelper' => $baseDir . '/lib/Model/SelectHelper.php',
    'OCA\\Talk\\Model\\Session' => $baseDir . '/lib/Model/Session.php',
    'OCA\\Talk\\Model\\SessionMapper' => $baseDir . '/lib/Model/SessionMapper.php',
    'OCA\\Talk\\Model\\Thread' => $baseDir . '/lib/Model/Thread.php',
    'OCA\\Talk\\Model\\ThreadAttendee' => $baseDir . '/lib/Model/ThreadAttendee.php',
    'OCA\\Talk\\Model\\ThreadAttendeeMapper' => $baseDir . '/lib/Model/ThreadAttendeeMapper.php',
    'OCA\\Talk\\Model\\ThreadMapper' => $baseDir . '/lib/Model/ThreadMapper.php',
    'OCA\\Talk\\Model\\Vote' => $baseDir . '/lib/Model/Vote.php',
    'OCA\\Talk\\Model\\VoteMapper' => $baseDir . '/lib/Model/VoteMapper.php',
    'OCA\\Talk\\Notification\\FederationChatNotifier' => $baseDir . '/lib/Notification/FederationChatNotifier.php',
    'OCA\\Talk\\Notification\\Listener' => $baseDir . '/lib/Notification/Listener.php',
    'OCA\\Talk\\Notification\\Notifier' => $baseDir . '/lib/Notification/Notifier.php',
    'OCA\\Talk\\OCP\\Conversation' => $baseDir . '/lib/OCP/Conversation.php',
    'OCA\\Talk\\OCP\\TalkBackend' => $baseDir . '/lib/OCP/TalkBackend.php',
    'OCA\\Talk\\OpenMetrics\\ActiveCalls' => $baseDir . '/lib/OpenMetrics/ActiveCalls.php',
    'OCA\\Talk\\OpenMetrics\\InCallSessions' => $baseDir . '/lib/OpenMetrics/InCallSessions.php',
    'OCA\\Talk\\Participant' => $baseDir . '/lib/Participant.php',
    'OCA\\Talk\\Profile\\TalkAction' => $baseDir . '/lib/Profile/TalkAction.php',
    'OCA\\Talk\\Profile\\TalkCallAction' => $baseDir . '/lib/Profile/TalkCallAction.php',
    'OCA\\Talk\\PublicShareAuth\\Listener' => $baseDir . '/lib/PublicShareAuth/Listener.php',
    'OCA\\Talk\\PublicShareAuth\\TemplateLoader' => $baseDir . '/lib/PublicShareAuth/TemplateLoader.php',
    'OCA\\Talk\\PublicShare\\TemplateLoader' => $baseDir . '/lib/PublicShare/TemplateLoader.php',
    'OCA\\Talk\\Recording\\BackendNotifier' => $baseDir . '/lib/Recording/BackendNotifier.php',
    'OCA\\Talk\\Recording\\Listener' => $baseDir . '/lib/Recording/Listener.php',
    'OCA\\Talk\\Recording\\RecordingFailedRequest' => $baseDir . '/lib/Recording/RecordingFailedRequest.php',
    'OCA\\Talk\\Recording\\RecordingRequest' => $baseDir . '/lib/Recording/RecordingRequest.php',
    'OCA\\Talk\\Recording\\RecordingStartedRequest' => $baseDir . '/lib/Recording/RecordingStartedRequest.php',
    'OCA\\Talk\\Recording\\RecordingStoppedRequest' => $baseDir . '/lib/Recording/RecordingStoppedRequest.php',
    'OCA\\Talk\\ResponseDefinitions' => $baseDir . '/lib/ResponseDefinitions.php',
    'OCA\\Talk\\Room' => $baseDir . '/lib/Room.php',
    'OCA\\Talk\\RoomAttributes' => $baseDir . '/lib/RoomAttributes.php',
    'OCA\\Talk\\RoomPresets\\APreset' => $baseDir . '/lib/RoomPresets/APreset.php',
    'OCA\\Talk\\RoomPresets\\DefaultPreset' => $baseDir . '/lib/RoomPresets/DefaultPreset.php',
    'OCA\\Talk\\RoomPresets\\Forced' => $baseDir . '/lib/RoomPresets/Forced.php',
    'OCA\\Talk\\RoomPresets\\Parameter' => $baseDir . '/lib/RoomPresets/Parameter.php',
    'OCA\\Talk\\RoomPresets\\Presentation' => $baseDir . '/lib/RoomPresets/Presentation.php',
    'OCA\\Talk\\RoomPresets\\VoiceRoom' => $baseDir . '/lib/RoomPresets/VoiceRoom.php',
    'OCA\\Talk\\RoomPresets\\Webinar' => $baseDir . '/lib/RoomPresets/Webinar.php',
    'OCA\\Talk\\Search\\ConversationSearch' => $baseDir . '/lib/Search/ConversationSearch.php',
    'OCA\\Talk\\Search\\CurrentMessageSearch' => $baseDir . '/lib/Search/CurrentMessageSearch.php',
    'OCA\\Talk\\Search\\MessageSearch' => $baseDir . '/lib/Search/MessageSearch.php',
    'OCA\\Talk\\Search\\UnifiedSearchCSSLoader' => $baseDir . '/lib/Search/UnifiedSearchCSSLoader.php',
    'OCA\\Talk\\Search\\UnifiedSearchFilterPlugin' => $baseDir . '/lib/Search/UnifiedSearchFilterPlugin.php',
    'OCA\\Talk\\Service\\ActivityPubHelper' => $baseDir . '/lib/Service/ActivityPubHelper.php',
    'OCA\\Talk\\Service\\AttachmentService' => $baseDir . '/lib/Service/AttachmentService.php',
    'OCA\\Talk\\Service\\AvatarService' => $baseDir . '/lib/Service/AvatarService.php',
    'OCA\\Talk\\Service\\BanService' => $baseDir . '/lib/Service/BanService.php',
    'OCA\\Talk\\Service\\BotService' => $baseDir . '/lib/Service/BotService.php',
    'OCA\\Talk\\Service\\BreakoutRoomService' => $baseDir . '/lib/Service/BreakoutRoomService.php',
    'OCA\\Talk\\Service\\CalendarIntegrationService' => $baseDir . '/lib/Service/CalendarIntegrationService.php',
    'OCA\\Talk\\Service\\CertificateService' => $baseDir . '/lib/Service/CertificateService.php',
    'OCA\\Talk\\Service\\ChecksumVerificationService' => $baseDir . '/lib/Service/ChecksumVerificationService.php',
    'OCA\\Talk\\Service\\ConsentService' => $baseDir . '/lib/Service/ConsentService.php',
    'OCA\\Talk\\Service\\ConversationFolderService' => $baseDir . '/lib/Service/ConversationFolderService.php',
    'OCA\\Talk\\Service\\ConversationTagService' => $baseDir . '/lib/Service/ConversationTagService.php',
    'OCA\\Talk\\Service\\EmojiService' => $baseDir . '/lib/Service/EmojiService.php',
    'OCA\\Talk\\Service\\HostedSignalingServerService' => $baseDir . '/lib/Service/HostedSignalingServerService.php',
    'OCA\\Talk\\Service\\InvitationService' => $baseDir . '/lib/Service/InvitationService.php',
    'OCA\\Talk\\Service\\LiveTranscriptionService' => $baseDir . '/lib/Service/LiveTranscriptionService.php',
    'OCA\\Talk\\Service\\MembershipService' => $baseDir . '/lib/Service/MembershipService.php',
    'OCA\\Talk\\Service\\MetricsService' => $baseDir . '/lib/Service/MetricsService.php',
    'OCA\\Talk\\Service\\NoteToSelfService' => $baseDir . '/lib/Service/NoteToSelfService.php',
    'OCA\\Talk\\Service\\ParticipantService' => $baseDir . '/lib/Service/ParticipantService.php',
    'OCA\\Talk\\Service\\PhoneNumberValidation' => $baseDir . '/lib/Service/PhoneNumberValidation.php',
    'OCA\\Talk\\Service\\PhoneService' => $baseDir . '/lib/Service/PhoneService.php',
    'OCA\\Talk\\Service\\PollExportService' => $baseDir . '/lib/Service/PollExportService.php',
    'OCA\\Talk\\Service\\PollService' => $baseDir . '/lib/Service/PollService.php',
    'OCA\\Talk\\Service\\ProxyCacheMessageService' => $baseDir . '/lib/Service/ProxyCacheMessageService.php',
    'OCA\\Talk\\Service\\RecordingService' => $baseDir . '/lib/Service/RecordingService.php',
    'OCA\\Talk\\Service\\ReminderService' => $baseDir . '/lib/Service/ReminderService.php',
    'OCA\\Talk\\Service\\RoomFormatter' => $baseDir . '/lib/Service/RoomFormatter.php',
    'OCA\\Talk\\Service\\RoomPresetFactory' => $baseDir . '/lib/Service/RoomPresetFactory.php',
    'OCA\\Talk\\Service\\RoomService' => $baseDir . '/lib/Service/RoomService.php',
    'OCA\\Talk\\Service\\SIPDialOutService' => $baseDir . '/lib/Service/SIPDialOutService.php',
    'OCA\\Talk\\Service\\SampleConversationsService' => $baseDir . '/lib/Service/SampleConversationsService.php',
    'OCA\\Talk\\Service\\ScheduledMessageService' => $baseDir . '/lib/Service/ScheduledMessageService.php',
    'OCA\\Talk\\Service\\SessionService' => $baseDir . '/lib/Service/SessionService.php',
    'OCA\\Talk\\Service\\ThreadService' => $baseDir . '/lib/Service/ThreadService.php',
    'OCA\\Talk\\Settings\\Admin\\AdminSettings' => $baseDir . '/lib/Settings/Admin/AdminSettings.php',
    'OCA\\Talk\\Settings\\Admin\\Section' => $baseDir . '/lib/Settings/Admin/Section.php',
    'OCA\\Talk\\Settings\\BeforePreferenceSetEventListener' => $baseDir . '/lib/Settings/BeforePreferenceSetEventListener.php',
    'OCA\\Talk\\Settings\\Personal' => $baseDir . '/lib/Settings/Personal.php',
    'OCA\\Talk\\Settings\\UserPreference' => $baseDir . '/lib/Settings/UserPreference.php',
    'OCA\\Talk\\SetupCheck\\BackgroundBlurLoading' => $baseDir . '/lib/SetupCheck/BackgroundBlurLoading.php',
    'OCA\\Talk\\SetupCheck\\Configuration' => $baseDir . '/lib/SetupCheck/Configuration.php',
    'OCA\\Talk\\SetupCheck\\FederationLockCache' => $baseDir . '/lib/SetupCheck/FederationLockCache.php',
    'OCA\\Talk\\SetupCheck\\HighPerformanceBackend' => $baseDir . '/lib/SetupCheck/HighPerformanceBackend.php',
    'OCA\\Talk\\SetupCheck\\NotifyPush' => $baseDir . '/lib/SetupCheck/NotifyPush.php',
    'OCA\\Talk\\SetupCheck\\RecordingBackend' => $baseDir . '/lib/SetupCheck/RecordingBackend.php',
    'OCA\\Talk\\SetupCheck\\SIPConfiguration' => $baseDir . '/lib/SetupCheck/SIPConfiguration.php',
    'OCA\\Talk\\Share\\Helper\\DeletedShareAPIController' => $baseDir . '/lib/Share/Helper/DeletedShareAPIController.php',
    'OCA\\Talk\\Share\\Helper\\FilesMetadataCache' => $baseDir . '/lib/Share/Helper/FilesMetadataCache.php',
    'OCA\\Talk\\Share\\Helper\\Preloader' => $baseDir . '/lib/Share/Helper/Preloader.php',
    'OCA\\Talk\\Share\\Helper\\ShareAPIController' => $baseDir . '/lib/Share/Helper/ShareAPIController.php',
    'OCA\\Talk\\Share\\Listener' => $baseDir . '/lib/Share/Listener.php',
    'OCA\\Talk\\Share\\RoomShareProvider' => $baseDir . '/lib/Share/RoomShareProvider.php',
    'OCA\\Talk\\Signaling\\BackendNotifier' => $baseDir . '/lib/Signaling/BackendNotifier.php',
    'OCA\\Talk\\Signaling\\Listener' => $baseDir . '/lib/Signaling/Listener.php',
    'OCA\\Talk\\Signaling\\Manager' => $baseDir . '/lib/Signaling/Manager.php',
    'OCA\\Talk\\Signaling\\Messages' => $baseDir . '/lib/Signaling/Messages.php',
    'OCA\\Talk\\Signaling\\Responses\\DialOut' => $baseDir . '/lib/Signaling/Responses/DialOut.php',
    'OCA\\Talk\\Signaling\\Responses\\DialOutError' => $baseDir . '/lib/Signaling/Responses/DialOutError.php',
    'OCA\\Talk\\Signaling\\Responses\\Response' => $baseDir . '/lib/Signaling/Responses/Response.php',
    'OCA\\Talk\\Signaling\\RoomPropertiesHelper' => $baseDir . '/lib/Signaling/RoomPropertiesHelper.php',
    'OCA\\Talk\\Status\\Listener' => $baseDir . '/lib/Status/Listener.php',
    'OCA\\Talk\\TalkSession' => $baseDir . '/lib/TalkSession.php',
    'OCA\\Talk\\Team\\TalkTeamResourceProvider' => $baseDir . '/lib/Team/TalkTeamResourceProvider.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Cache\\Cache' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Cache/Cache.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Cache\\CacheEntry' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Cache/CacheEntry.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Cache\\Exception\\CacheDirectoryNotWritable' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Cache/Exception/CacheDirectoryNotWritable.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Cache\\Exception\\CompiledPhpCacheFileNotWritten' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Cache/Exception/CompiledPhpCacheFileNotWritten.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Cache\\Exception\\CorruptedCompiledPhpCacheFile' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Cache/Exception/CorruptedCompiledPhpCacheFile.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Cache\\Exception\\InvalidSignatureToWarmup' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Cache/Exception/InvalidSignatureToWarmup.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Cache\\FileSystemCache' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Cache/FileSystemCache.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Cache\\FileWatchingCache' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Cache/FileWatchingCache.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Cache\\KeySanitizerCache' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Cache/KeySanitizerCache.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Cache\\RuntimeCache' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Cache/RuntimeCache.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Cache\\TypeFilesWatcher' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Cache/TypeFilesWatcher.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Cache\\Warmup\\RecursiveCacheWarmupService' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Cache/Warmup/RecursiveCacheWarmupService.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Compiler' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Compiler.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Library\\NewAttributeNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Library/NewAttributeNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Library\\TypeAcceptNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Library/TypeAcceptNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\AnonymousClassNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/AnonymousClassNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\ArrayKeyAccessNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/ArrayKeyAccessNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\ArrayNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/ArrayNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\AssignNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/AssignNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\CallNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/CallNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\CastNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/CastNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\ClassNameNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/ClassNameNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\ClassNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/ClassNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\CloneNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/CloneNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\ClosureNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/ClosureNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\ComplianceNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/ComplianceNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\DifferentNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/DifferentNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\EqualsNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/EqualsNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\ExpressionNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/ExpressionNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\ForEachNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/ForEachNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\FunctionCallNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/FunctionCallNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\FunctionNameNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/FunctionNameNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\GreaterOrEqualsToNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/GreaterOrEqualsToNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\GreaterThanNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/GreaterThanNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\IfNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/IfNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\InstanceOfNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/InstanceOfNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\LessOrEqualsToNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/LessOrEqualsToNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\LessThanNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/LessThanNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\LogicalAndNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/LogicalAndNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\LogicalOrNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/LogicalOrNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\MatchNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/MatchNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\MethodCallNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/MethodCallNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\MethodNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/MethodNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\NegateNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/NegateNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\NewClassNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/NewClassNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\ParameterDeclarationNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/ParameterDeclarationNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\PhpFileNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/PhpFileNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\PropertyDeclarationNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/PropertyDeclarationNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\PropertyNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/PropertyNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\ReturnNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/ReturnNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\ShortClosureNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/ShortClosureNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\StaticAccessNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/StaticAccessNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\StaticMethodCallNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/StaticMethodCallNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\TernaryNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/TernaryNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\ThrowNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/ThrowNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\ValueNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/ValueNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\VariableAccessNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/VariableAccessNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\VariableNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/VariableNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\WrapNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/WrapNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\YieldNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Native/YieldNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Node' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Compiler/Node.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\AttributeDefinition' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/AttributeDefinition.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Attributes' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Attributes.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\ClassDefinition' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/ClassDefinition.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\FunctionDefinition' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/FunctionDefinition.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\FunctionObject' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/FunctionObject.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\FunctionsContainer' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/FunctionsContainer.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\MethodDefinition' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/MethodDefinition.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Methods' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Methods.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\ParameterDefinition' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/ParameterDefinition.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Parameters' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Parameters.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Properties' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Properties.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\PropertyDefinition' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/PropertyDefinition.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\AttributesRepository' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/AttributesRepository.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Cache\\CompiledClassDefinitionRepository' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/Cache/CompiledClassDefinitionRepository.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Cache\\CompiledFunctionDefinitionRepository' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/Cache/CompiledFunctionDefinitionRepository.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Cache\\Compiler\\AttributesCompiler' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/Cache/Compiler/AttributesCompiler.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Cache\\Compiler\\ClassDefinitionCompiler' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/Cache/Compiler/ClassDefinitionCompiler.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Cache\\Compiler\\Exception\\TypeCannotBeCompiled' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/Cache/Compiler/Exception/TypeCannotBeCompiled.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Cache\\Compiler\\FunctionDefinitionCompiler' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/Cache/Compiler/FunctionDefinitionCompiler.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Cache\\Compiler\\MethodDefinitionCompiler' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/Cache/Compiler/MethodDefinitionCompiler.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Cache\\Compiler\\ParameterDefinitionCompiler' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/Cache/Compiler/ParameterDefinitionCompiler.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Cache\\Compiler\\PropertyDefinitionCompiler' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/Cache/Compiler/PropertyDefinitionCompiler.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Cache\\Compiler\\TypeCompiler' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/Cache/Compiler/TypeCompiler.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Cache\\InMemoryClassDefinitionRepository' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/Cache/InMemoryClassDefinitionRepository.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Cache\\InMemoryFunctionDefinitionRepository' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/Cache/InMemoryFunctionDefinitionRepository.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\ClassDefinitionRepository' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/ClassDefinitionRepository.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\FunctionDefinitionRepository' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/FunctionDefinitionRepository.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\ReflectionAttributesRepository' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/Reflection/ReflectionAttributesRepository.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\ReflectionClassDefinitionRepository' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/Reflection/ReflectionClassDefinitionRepository.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\ReflectionFunctionDefinitionRepository' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/Reflection/ReflectionFunctionDefinitionRepository.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\ReflectionMethodDefinitionBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/Reflection/ReflectionMethodDefinitionBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\ReflectionParameterDefinitionBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/Reflection/ReflectionParameterDefinitionBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\ReflectionPropertyDefinitionBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/Reflection/ReflectionPropertyDefinitionBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\TypeResolver\\ClassGenericResolver' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/Reflection/TypeResolver/ClassGenericResolver.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\TypeResolver\\ClassImportedTypeAliasResolver' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/Reflection/TypeResolver/ClassImportedTypeAliasResolver.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\TypeResolver\\ClassLocalTypeAliasResolver' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/Reflection/TypeResolver/ClassLocalTypeAliasResolver.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\TypeResolver\\ClassParentTypeResolver' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/Reflection/TypeResolver/ClassParentTypeResolver.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\TypeResolver\\FunctionReturnTypeResolver' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/Reflection/TypeResolver/FunctionReturnTypeResolver.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\TypeResolver\\ParameterTypeResolver' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/Reflection/TypeResolver/ParameterTypeResolver.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\TypeResolver\\PropertyTypeResolver' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/Reflection/TypeResolver/PropertyTypeResolver.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\TypeResolver\\ReflectionTypeResolver' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/Reflection/TypeResolver/ReflectionTypeResolver.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\TypeResolver\\TemplateResolver' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Definition/Repository/Reflection/TypeResolver/TemplateResolver.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Library\\Container' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Library/Container.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Library\\Settings' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Library/Settings.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\MapperBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/MapperBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\ArgumentsMapper' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/ArgumentsMapper.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\ArgumentsMapperError' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/ArgumentsMapperError.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\AsConverter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/AsConverter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Configurator\\ConvertKeysToCamelCase' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Configurator/ConvertKeysToCamelCase.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Configurator\\ConvertKeysToSnakeCase' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Configurator/ConvertKeysToSnakeCase.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Configurator\\MapperBuilderConfigurator' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Configurator/MapperBuilderConfigurator.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Configurator\\RestrictKeysToCamelCase' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Configurator/RestrictKeysToCamelCase.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Configurator\\RestrictKeysToKebabCase' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Configurator/RestrictKeysToKebabCase.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Configurator\\RestrictKeysToPascalCase' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Configurator/RestrictKeysToPascalCase.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Configurator\\RestrictKeysToSnakeCase' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Configurator/RestrictKeysToSnakeCase.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Exception\\InvalidMappingTypeSignature' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Exception/InvalidMappingTypeSignature.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Exception\\MappingLogicalException' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Exception/MappingLogicalException.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Exception\\PsrRequestParsedBodyIsObject' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Exception/PsrRequestParsedBodyIsObject.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Exception\\TypeErrorDuringArgumentsMapping' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Exception/TypeErrorDuringArgumentsMapping.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Exception\\TypeErrorDuringMapping' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Exception/TypeErrorDuringMapping.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Http\\FromBody' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Http/FromBody.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Http\\FromQuery' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Http/FromQuery.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Http\\FromRoute' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Http/FromRoute.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Http\\HttpRequest' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Http/HttpRequest.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\MappingError' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/MappingError.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Argument' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/Argument.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Arguments' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/Arguments.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\ArgumentsValues' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/ArgumentsValues.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Constructor' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/Constructor.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\DateTimeFormatConstructor' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/DateTimeFormatConstructor.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\DynamicConstructor' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/DynamicConstructor.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Exception\\CannotFindObjectBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/Exception/CannotFindObjectBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Exception\\CannotInstantiateObject' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/Exception/CannotInstantiateObject.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Exception\\CannotParseToDateTime' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/Exception/CannotParseToDateTime.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Exception\\InvalidConstructorClassTypeParameter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/Exception/InvalidConstructorClassTypeParameter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Exception\\InvalidConstructorMethodWithAttributeReturnType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/Exception/InvalidConstructorMethodWithAttributeReturnType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Exception\\InvalidConstructorReturnType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/Exception/InvalidConstructorReturnType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Exception\\MissingConstructorClassTypeParameter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/Exception/MissingConstructorClassTypeParameter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Exception\\ObjectBuildersCollision' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/Exception/ObjectBuildersCollision.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Exception\\PermissiveTypeNotAllowed' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/Exception/PermissiveTypeNotAllowed.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Factory\\CircularDependencyDetectorObjectBuilderFactory' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/Factory/CircularDependencyDetectorObjectBuilderFactory.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Factory\\ConstructorObjectBuilderFactory' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/Factory/ConstructorObjectBuilderFactory.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Factory\\DateTimeObjectBuilderFactory' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/Factory/DateTimeObjectBuilderFactory.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Factory\\DateTimeZoneObjectBuilderFactory' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/Factory/DateTimeZoneObjectBuilderFactory.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Factory\\InMemoryObjectBuilderFactory' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/Factory/InMemoryObjectBuilderFactory.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Factory\\ObjectBuilderFactory' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/Factory/ObjectBuilderFactory.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Factory\\ReflectionObjectBuilderFactory' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/Factory/ReflectionObjectBuilderFactory.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Factory\\SortingObjectBuilderFactory' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/Factory/SortingObjectBuilderFactory.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Factory\\StrictTypesObjectBuilderFactory' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/Factory/StrictTypesObjectBuilderFactory.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\FunctionObjectBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/FunctionObjectBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\MethodArguments' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/MethodArguments.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\MethodObjectBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/MethodObjectBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\NativeConstructorObjectBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/NativeConstructorObjectBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\NativeEnumObjectBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/NativeEnumObjectBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\ObjectBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/ObjectBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\ReflectionObjectBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Object/ReflectionObjectBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Source\\Exception\\FileExtensionNotHandled' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Source/Exception/FileExtensionNotHandled.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Source\\Exception\\InvalidJson' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Source/Exception/InvalidJson.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Source\\Exception\\InvalidSource' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Source/Exception/InvalidSource.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Source\\Exception\\InvalidYaml' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Source/Exception/InvalidYaml.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Source\\Exception\\SourceNotIterable' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Source/Exception/SourceNotIterable.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Source\\Exception\\UnableToReadFile' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Source/Exception/UnableToReadFile.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Source\\Exception\\YamlExtensionNotEnabled' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Source/Exception/YamlExtensionNotEnabled.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Source\\FileSource' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Source/FileSource.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Source\\JsonSource' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Source/JsonSource.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Source\\Modifier\\CamelCaseKeys' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Source/Modifier/CamelCaseKeys.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Source\\Modifier\\Mapping' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Source/Modifier/Mapping.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Source\\Modifier\\PathMapping' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Source/Modifier/PathMapping.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Source\\Source' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Source/Source.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Source\\YamlSource' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Source/YamlSource.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\TreeMapper' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/TreeMapper.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\ArrayNodeBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Builder/ArrayNodeBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\ConverterContainer' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Builder/ConverterContainer.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\HttpRequestNodeBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Builder/HttpRequestNodeBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\InterfaceInferringContainer' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Builder/InterfaceInferringContainer.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\InterfaceNodeBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Builder/InterfaceNodeBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\KeyConversionPipeline' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Builder/KeyConversionPipeline.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\KeyConverterNodeBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Builder/KeyConverterNodeBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\ListNodeBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Builder/ListNodeBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\MixedNodeBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Builder/MixedNodeBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\Node' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Builder/Node.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\NodeBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Builder/NodeBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\NullNodeBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Builder/NullNodeBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\ObjectNodeBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Builder/ObjectNodeBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\ScalarNodeBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Builder/ScalarNodeBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\ShapedArrayNodeBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Builder/ShapedArrayNodeBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\TypeNodeBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Builder/TypeNodeBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\UndefinedObjectNodeBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Builder/UndefinedObjectNodeBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\UnionNodeBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Builder/UnionNodeBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\ValueConverterNodeBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Builder/ValueConverterNodeBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\CannotInferFinalClass' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/CannotInferFinalClass.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\CannotMapHttpRequestToUnsealedShapedArray' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/CannotMapHttpRequestToUnsealedShapedArray.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\CannotMapToPermissiveType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/CannotMapToPermissiveType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\CannotResolveObjectType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/CannotResolveObjectType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\CannotResolveTypeFromUnion' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/CannotResolveTypeFromUnion.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\CannotUseBothFromBodyAttributes' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/CannotUseBothFromBodyAttributes.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\CannotUseBothFromQueryAttributes' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/CannotUseBothFromQueryAttributes.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\CircularDependencyDetected' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/CircularDependencyDetected.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\ConverterHasInvalidCallableParameter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/ConverterHasInvalidCallableParameter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\ConverterHasInvalidReturnType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/ConverterHasInvalidReturnType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\ConverterHasNoParameter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/ConverterHasNoParameter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\ConverterHasTooManyParameters' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/ConverterHasTooManyParameters.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\HttpRequestKeyCollision' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/HttpRequestKeyCollision.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\InterfaceHasBothConstructorAndInfer' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/InterfaceHasBothConstructorAndInfer.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\InvalidArrayKey' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/InvalidArrayKey.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\InvalidIterableKeyType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/InvalidIterableKeyType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\InvalidListKey' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/InvalidListKey.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\InvalidNodeDuringValueConversion' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/InvalidNodeDuringValueConversion.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\InvalidNodeValue' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/InvalidNodeValue.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\InvalidResolvedImplementationValue' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/InvalidResolvedImplementationValue.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\KeyConverterHasInvalidStringParameter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/KeyConverterHasInvalidStringParameter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\KeyConverterHasNoParameter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/KeyConverterHasNoParameter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\KeyConverterHasTooManyParameters' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/KeyConverterHasTooManyParameters.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\KeysCollision' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/KeysCollision.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\MissingNodeValue' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/MissingNodeValue.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\MissingObjectImplementationRegistration' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/MissingObjectImplementationRegistration.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\ObjectImplementationCallbackError' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/ObjectImplementationCallbackError.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\ObjectImplementationNotRegistered' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/ObjectImplementationNotRegistered.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\ResolvedImplementationIsNotAccepted' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/ResolvedImplementationIsNotAccepted.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\SourceIsEmptyArray' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/SourceIsEmptyArray.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\SourceIsEmptyList' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/SourceIsEmptyList.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\SourceIsNotNull' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/SourceIsNotNull.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\SourceMustBeIterable' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/SourceMustBeIterable.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\TooManyResolvedTypesFromUnion' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/TooManyResolvedTypesFromUnion.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\UnexpectedKeyInSource' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/UnexpectedKeyInSource.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\UnresolvableShellType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Exception/UnresolvableShellType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\DefaultMessage' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Message/DefaultMessage.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\ErrorMessage' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Message/ErrorMessage.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\Formatter\\AggregateMessageFormatter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Message/Formatter/AggregateMessageFormatter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\Formatter\\CallbackMessageFormatter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Message/Formatter/CallbackMessageFormatter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\Formatter\\LocaleMessageFormatter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Message/Formatter/LocaleMessageFormatter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\Formatter\\MessageFormatter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Message/Formatter/MessageFormatter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\Formatter\\MessageMapFormatter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Message/Formatter/MessageMapFormatter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\Formatter\\TranslationMessageFormatter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Message/Formatter/TranslationMessageFormatter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\HasCode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Message/HasCode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\HasParameters' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Message/HasParameters.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\Message' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Message/Message.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\MessageBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Message/MessageBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\Messages' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Message/Messages.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\NodeMessage' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Message/NodeMessage.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\UserlandError' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Message/UserlandError.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\RootNodeBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/RootNodeBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Shell' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/Tree/Shell.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\TypeArgumentsMapper' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/TypeArgumentsMapper.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\TypeTreeMapper' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/TypeTreeMapper.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\TypeTreeMapperError' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Mapper/TypeTreeMapperError.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\NormalizerBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/NormalizerBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\ArrayNormalizer' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/ArrayNormalizer.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\AsTransformer' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/AsTransformer.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Configurator\\NormalizerBuilderConfigurator' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Configurator/NormalizerBuilderConfigurator.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Exception\\CircularReferenceFoundDuringNormalization' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Exception/CircularReferenceFoundDuringNormalization.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Exception\\KeyTransformerHasTooManyParameters' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Exception/KeyTransformerHasTooManyParameters.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Exception\\KeyTransformerParameterInvalidType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Exception/KeyTransformerParameterInvalidType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Exception\\TransformerHasInvalidCallableParameter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Exception/TransformerHasInvalidCallableParameter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Exception\\TransformerHasNoParameter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Exception/TransformerHasNoParameter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Exception\\TransformerHasTooManyParameters' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Exception/TransformerHasTooManyParameters.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Exception\\TypeUnhandledByNormalizer' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Exception/TypeUnhandledByNormalizer.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Format' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Format.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Formatter\\Exception\\CannotFormatInvalidTypeToJson' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Formatter/Exception/CannotFormatInvalidTypeToJson.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Formatter\\JsonFormatter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Formatter/JsonFormatter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\JsonNormalizer' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/JsonNormalizer.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Normalizer' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Normalizer.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\StreamNormalizer' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/StreamNormalizer.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\CompiledTransformer' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Transformer/CompiledTransformer.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TransformerDefinition' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Transformer/Compiler/TransformerDefinition.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TransformerDefinitionBuilder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Transformer/Compiler/TransformerDefinitionBuilder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TransformerRootNode' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Transformer/Compiler/TransformerRootNode.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\ClassFormatter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/ClassFormatter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\DateTimeFormatter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/DateTimeFormatter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\DateTimeZoneFormatter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/DateTimeZoneFormatter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\EnumFormatter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/EnumFormatter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\InterfaceFormatter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/InterfaceFormatter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\MixedFormatter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/MixedFormatter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\NullFormatter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/NullFormatter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\RegisteredTransformersFormatter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/RegisteredTransformersFormatter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\ScalarFormatter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/ScalarFormatter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\ShapedArrayFormatter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/ShapedArrayFormatter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\StdClassFormatter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/StdClassFormatter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\TraversableFormatter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/TraversableFormatter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\TypeFormatter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/TypeFormatter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\UnionFormatter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/UnionFormatter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\UnitEnumFormatter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/UnitEnumFormatter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\UnsureTypeFormatter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/UnsureTypeFormatter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\EmptyObject' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Transformer/EmptyObject.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\RecursiveTransformer' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Transformer/RecursiveTransformer.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Transformer' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Transformer/Transformer.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\TransformerContainer' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Normalizer/Transformer/TransformerContainer.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\BooleanType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/BooleanType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\ClassType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/ClassType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\CombiningType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/CombiningType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\CompositeTraversableType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/CompositeTraversableType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\CompositeType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/CompositeType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\DumpableType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/DumpableType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Dumper\\TypeDumpContext' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Dumper/TypeDumpContext.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Dumper\\TypeDumper' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Dumper/TypeDumper.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\FixedType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/FixedType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\FloatType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/FloatType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\IntegerType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/IntegerType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\ObjectType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/ObjectType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\ObjectWithGenericType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/ObjectWithGenericType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\CachedParser' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/CachedParser.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Callable\\ExpectedClosingParenthesisAfterCallable' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Callable/ExpectedClosingParenthesisAfterCallable.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Callable\\ExpectedColonAfterCallableClosingParenthesis' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Callable/ExpectedColonAfterCallableClosingParenthesis.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Callable\\ExpectedReturnTypeAfterCallableColon' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Callable/ExpectedReturnTypeAfterCallableColon.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Callable\\ExpectedTypeForCallable' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Callable/ExpectedTypeForCallable.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Callable\\UnexpectedTokenAfterCallableClosingParenthesis' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Callable/UnexpectedTokenAfterCallableClosingParenthesis.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Constant\\ClassConstantCaseNotFound' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Constant/ClassConstantCaseNotFound.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Constant\\MissingClassConstantCase' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Constant/MissingClassConstantCase.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Enum\\EnumCaseNotFound' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Enum/EnumCaseNotFound.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Enum\\EnumHasNoCase' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Enum/EnumHasNoCase.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Enum\\MissingEnumCase' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Enum/MissingEnumCase.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Enum\\MissingSpecificEnumCase' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Enum/MissingSpecificEnumCase.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Generic\\CannotAssignGeneric' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Generic/CannotAssignGeneric.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Generic\\GenericClosingBracketMissing' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Generic/GenericClosingBracketMissing.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Generic\\GenericCommaMissing' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Generic/GenericCommaMissing.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Generic\\MissingGenerics' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Generic/MissingGenerics.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Intersection\\InvalidIntersectionElement' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Intersection/InvalidIntersectionElement.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Intersection\\RightIntersectionTypeMissing' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Intersection/RightIntersectionTypeMissing.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\InvalidType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/InvalidType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\ArrayClosingBracketMissing' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Iterable/ArrayClosingBracketMissing.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\ArrayCommaMissing' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Iterable/ArrayCommaMissing.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\ArrayExpectedCommaOrClosingBracket' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Iterable/ArrayExpectedCommaOrClosingBracket.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\ArrayMissingSubType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Iterable/ArrayMissingSubType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\InvalidArrayKey' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Iterable/InvalidArrayKey.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\InvalidShapedArrayUnsealedType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Iterable/InvalidShapedArrayUnsealedType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\ListClosingBracketMissing' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Iterable/ListClosingBracketMissing.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\ListMissingSubType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Iterable/ListMissingSubType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\ShapedArrayClosingBracketMissing' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Iterable/ShapedArrayClosingBracketMissing.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\ShapedArrayColonTokenMissing' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Iterable/ShapedArrayColonTokenMissing.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\ShapedArrayCommaMissing' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Iterable/ShapedArrayCommaMissing.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\ShapedArrayElementDuplicatedKey' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Iterable/ShapedArrayElementDuplicatedKey.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\ShapedArrayElementTypeMissing' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Iterable/ShapedArrayElementTypeMissing.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\ShapedArrayUnexpectedTokenAfterSealedType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Iterable/ShapedArrayUnexpectedTokenAfterSealedType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\ShapedArrayWithoutElementsWithSealedType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Iterable/ShapedArrayWithoutElementsWithSealedType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\SimpleArrayClosingBracketMissing' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Iterable/SimpleArrayClosingBracketMissing.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Magic\\ValueOfClosingBracketMissing' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Magic/ValueOfClosingBracketMissing.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Magic\\ValueOfIncorrectSubType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Magic/ValueOfIncorrectSubType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Magic\\ValueOfMissingSubType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Magic/ValueOfMissingSubType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Magic\\ValueOfOpeningBracketMissing' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Magic/ValueOfOpeningBracketMissing.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\MissingClosingQuoteChar' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/MissingClosingQuoteChar.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Scalar\\ClassStringClosingBracketMissing' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Scalar/ClassStringClosingBracketMissing.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Scalar\\ClassStringMissingSubType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Scalar/ClassStringMissingSubType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Scalar\\IntegerRangeInvalidMaxValue' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Scalar/IntegerRangeInvalidMaxValue.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Scalar\\IntegerRangeInvalidMinValue' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Scalar/IntegerRangeInvalidMinValue.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Scalar\\IntegerRangeMissingClosingBracket' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Scalar/IntegerRangeMissingClosingBracket.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Scalar\\IntegerRangeMissingComma' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Scalar/IntegerRangeMissingComma.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Scalar\\IntegerRangeMissingMaxValue' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Scalar/IntegerRangeMissingMaxValue.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Scalar\\IntegerRangeMissingMinValue' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Scalar/IntegerRangeMissingMinValue.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Scalar\\NullableMissingRightType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Scalar/NullableMissingRightType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Scalar\\ReversedValuesForIntegerRange' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Scalar/ReversedValuesForIntegerRange.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Scalar\\SameValueForIntegerRange' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Scalar/SameValueForIntegerRange.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\UnexpectedToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/UnexpectedToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Union\\ForbiddenMixedType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Union/ForbiddenMixedType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Union\\InvalidClassStringElements' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Union/InvalidClassStringElements.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Union\\RightUnionTypeMissing' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Exception/Union/RightUnionTypeMissing.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Factory\\Specifications\\AliasSpecification' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Factory/Specifications/AliasSpecification.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Factory\\Specifications\\ClassContextSpecification' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Factory/Specifications/ClassContextSpecification.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Factory\\Specifications\\ObjectSpecification' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Factory/Specifications/ObjectSpecification.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Factory\\Specifications\\TypeParserSpecification' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Factory/Specifications/TypeParserSpecification.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Factory\\TypeParserFactory' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Factory/TypeParserFactory.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\NativeLexer' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/NativeLexer.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\SpecificationsLexer' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/SpecificationsLexer.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\TokenStream' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/TokenStream.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\ArrayToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/ArrayToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\CallableToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/CallableToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\CaseFinder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/CaseFinder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\ClassNameToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/ClassNameToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\ClassStringToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/ClassStringToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\ClosingBracketToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/ClosingBracketToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\ClosingCurlyBracketToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/ClosingCurlyBracketToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\ClosingParenthesisToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/ClosingParenthesisToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\ClosingSquareBracketToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/ClosingSquareBracketToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\ColonToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/ColonToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\CommaToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/CommaToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\DoubleColonToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/DoubleColonToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\EnumNameToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/EnumNameToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\FloatValueToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/FloatValueToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\IntegerToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/IntegerToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\IntegerValueToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/IntegerValueToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\IntersectionToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/IntersectionToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\LeftTraversingToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/LeftTraversingToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\ListToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/ListToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\NullableToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/NullableToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\ObjectToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/ObjectToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\OpeningBracketToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/OpeningBracketToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\OpeningCurlyBracketToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/OpeningCurlyBracketToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\OpeningParenthesisToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/OpeningParenthesisToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\OpeningSquareBracketToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/OpeningSquareBracketToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\StringValueToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/StringValueToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\Token' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/Token.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\TraversingToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/TraversingToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\TripleDotsToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/TripleDotsToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\TypeToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/TypeToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\UnionToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/UnionToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\VacantToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/VacantToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\ValueOfToken' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/Token/ValueOfToken.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\TokenizedAnnotation' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/TokenizedAnnotation.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\TokensExtractor' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/TokensExtractor.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\TypeLexer' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/Lexer/TypeLexer.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\LexingParser' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/LexingParser.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\TypeParser' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/TypeParser.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\UnresolvableTypeFinderParser' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/UnresolvableTypeFinderParser.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\VacantTypeAssignerParser' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Parser/VacantTypeAssignerParser.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\ScalarType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/ScalarType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\StringType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/StringType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Type' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Type.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\ArrayKeyType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/ArrayKeyType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\ArrayType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/ArrayType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\BooleanValueType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/BooleanValueType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\CallableType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/CallableType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\ClassStringType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/ClassStringType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\EnumType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/EnumType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\Factory\\CannotBuildTypeFromValue' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/Factory/CannotBuildTypeFromValue.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\Factory\\ValueTypeFactory' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/Factory/ValueTypeFactory.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\FloatValueType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/FloatValueType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\GenericType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/GenericType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\Generics' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/Generics.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\IntegerRangeType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/IntegerRangeType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\IntegerValueType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/IntegerValueType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\InterfaceType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/InterfaceType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\IntersectionType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/IntersectionType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\IterableType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/IterableType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\ListType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/ListType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\MixedType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/MixedType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\NativeBooleanType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/NativeBooleanType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\NativeClassType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/NativeClassType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\NativeFloatType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/NativeFloatType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\NativeIntegerType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/NativeIntegerType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\NativeStringType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/NativeStringType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\NegativeIntegerType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/NegativeIntegerType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\NonEmptyArrayType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/NonEmptyArrayType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\NonEmptyListType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/NonEmptyListType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\NonEmptyStringType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/NonEmptyStringType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\NonNegativeIntegerType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/NonNegativeIntegerType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\NonPositiveIntegerType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/NonPositiveIntegerType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\NullType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/NullType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\NumericStringType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/NumericStringType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\PositiveIntegerType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/PositiveIntegerType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\ScalarConcreteType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/ScalarConcreteType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\ShapedArrayElement' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/ShapedArrayElement.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\ShapedArrayType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/ShapedArrayType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\StringValueType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/StringValueType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\UndefinedObjectType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/UndefinedObjectType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\UnionType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/UnionType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\UnresolvableType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/Types/UnresolvableType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\VacantType' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Type/VacantType.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Utility\\IsSingleton' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Utility/IsSingleton.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Utility\\Package' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Utility/Package.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Utility\\Polyfill' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Utility/Polyfill.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Utility\\Reflection\\Annotations' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Utility/Reflection/Annotations.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Utility\\Reflection\\NamespaceFinder' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Utility/Reflection/NamespaceFinder.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Utility\\Reflection\\PhpParser' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Utility/Reflection/PhpParser.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Utility\\Reflection\\Reflection' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Utility/Reflection/Reflection.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Utility\\Reflection\\TokenParser' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Utility/Reflection/TokenParser.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Utility\\String\\StringCutter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Utility/String/StringCutter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Utility\\String\\StringFormatter' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Utility/String/StringFormatter.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Utility\\String\\StringFormatterError' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Utility/String/StringFormatterError.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Utility\\TypeHelper' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Utility/TypeHelper.php',
    'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Utility\\ValueDumper' => $baseDir . '/lib/Vendor/CuyZ/Valinor/Utility/ValueDumper.php',
    'OCA\\Talk\\Vendor\\Firebase\\JWT\\BeforeValidException' => $baseDir . '/lib/Vendor/Firebase/JWT/BeforeValidException.php',
    'OCA\\Talk\\Vendor\\Firebase\\JWT\\CachedKeySet' => $baseDir . '/lib/Vendor/Firebase/JWT/CachedKeySet.php',
    'OCA\\Talk\\Vendor\\Firebase\\JWT\\ExpiredException' => $baseDir . '/lib/Vendor/Firebase/JWT/ExpiredException.php',
    'OCA\\Talk\\Vendor\\Firebase\\JWT\\JWK' => $baseDir . '/lib/Vendor/Firebase/JWT/JWK.php',
    'OCA\\Talk\\Vendor\\Firebase\\JWT\\JWT' => $baseDir . '/lib/Vendor/Firebase/JWT/JWT.php',
    'OCA\\Talk\\Vendor\\Firebase\\JWT\\JWTExceptionWithPayloadInterface' => $baseDir . '/lib/Vendor/Firebase/JWT/JWTExceptionWithPayloadInterface.php',
    'OCA\\Talk\\Vendor\\Firebase\\JWT\\Key' => $baseDir . '/lib/Vendor/Firebase/JWT/Key.php',
    'OCA\\Talk\\Vendor\\Firebase\\JWT\\SignatureInvalidException' => $baseDir . '/lib/Vendor/Firebase/JWT/SignatureInvalidException.php',
    'OCA\\Talk\\Webinary' => $baseDir . '/lib/Webinary.php',
    'cweagans\\Composer\\Capability\\CommandProvider' => $vendorDir . '/cweagans/composer-patches/src/Capability/CommandProvider.php',
    'cweagans\\Composer\\Capability\\Downloader\\BaseDownloaderProvider' => $vendorDir . '/cweagans/composer-patches/src/Capability/Downloader/BaseDownloaderProvider.php',
    'cweagans\\Composer\\Capability\\Downloader\\CoreDownloaderProvider' => $vendorDir . '/cweagans/composer-patches/src/Capability/Downloader/CoreDownloaderProvider.php',
    'cweagans\\Composer\\Capability\\Downloader\\DownloaderProvider' => $vendorDir . '/cweagans/composer-patches/src/Capability/Downloader/DownloaderProvider.php',
    'cweagans\\Composer\\Capability\\Patcher\\BasePatcherProvider' => $vendorDir . '/cweagans/composer-patches/src/Capability/Patcher/BasePatcherProvider.php',
    'cweagans\\Composer\\Capability\\Patcher\\CorePatcherProvider' => $vendorDir . '/cweagans/composer-patches/src/Capability/Patcher/CorePatcherProvider.php',
    'cweagans\\Composer\\Capability\\Patcher\\PatcherProvider' => $vendorDir . '/cweagans/composer-patches/src/Capability/Patcher/PatcherProvider.php',
    'cweagans\\Composer\\Capability\\Resolver\\BaseResolverProvider' => $vendorDir . '/cweagans/composer-patches/src/Capability/Resolver/BaseResolverProvider.php',
    'cweagans\\Composer\\Capability\\Resolver\\CoreResolverProvider' => $vendorDir . '/cweagans/composer-patches/src/Capability/Resolver/CoreResolverProvider.php',
    'cweagans\\Composer\\Capability\\Resolver\\ResolverProvider' => $vendorDir . '/cweagans/composer-patches/src/Capability/Resolver/ResolverProvider.php',
    'cweagans\\Composer\\Command\\DoctorCommand' => $vendorDir . '/cweagans/composer-patches/src/Command/DoctorCommand.php',
    'cweagans\\Composer\\Command\\PatchesCommandBase' => $vendorDir . '/cweagans/composer-patches/src/Command/PatchesCommandBase.php',
    'cweagans\\Composer\\Command\\RelockCommand' => $vendorDir . '/cweagans/composer-patches/src/Command/RelockCommand.php',
    'cweagans\\Composer\\Command\\RepatchCommand' => $vendorDir . '/cweagans/composer-patches/src/Command/RepatchCommand.php',
    'cweagans\\Composer\\ConfigurablePlugin' => $vendorDir . '/cweagans/composer-configurable-plugin/src/ConfigurablePlugin.php',
    'cweagans\\Composer\\Downloader' => $vendorDir . '/cweagans/composer-patches/src/Downloader.php',
    'cweagans\\Composer\\Downloader\\ComposerDownloader' => $vendorDir . '/cweagans/composer-patches/src/Downloader/ComposerDownloader.php',
    'cweagans\\Composer\\Downloader\\DownloaderBase' => $vendorDir . '/cweagans/composer-patches/src/Downloader/DownloaderBase.php',
    'cweagans\\Composer\\Downloader\\DownloaderInterface' => $vendorDir . '/cweagans/composer-patches/src/Downloader/DownloaderInterface.php',
    'cweagans\\Composer\\Downloader\\Exception\\HashMismatchException' => $vendorDir . '/cweagans/composer-patches/src/Downloader/Exception/HashMismatchException.php',
    'cweagans\\Composer\\Event\\PatchEvent' => $vendorDir . '/cweagans/composer-patches/src/Event/PatchEvent.php',
    'cweagans\\Composer\\Event\\PatchEvents' => $vendorDir . '/cweagans/composer-patches/src/Event/PatchEvents.php',
    'cweagans\\Composer\\Event\\PluginEvent' => $vendorDir . '/cweagans/composer-patches/src/Event/PluginEvent.php',
    'cweagans\\Composer\\Event\\PluginEvents' => $vendorDir . '/cweagans/composer-patches/src/Event/PluginEvents.php',
    'cweagans\\Composer\\Locker' => $vendorDir . '/cweagans/composer-patches/src/Locker.php',
    'cweagans\\Composer\\Patch' => $vendorDir . '/cweagans/composer-patches/src/Patch.php',
    'cweagans\\Composer\\PatchCollection' => $vendorDir . '/cweagans/composer-patches/src/PatchCollection.php',
    'cweagans\\Composer\\Patcher' => $vendorDir . '/cweagans/composer-patches/src/Patcher.php',
    'cweagans\\Composer\\Patcher\\FreeformPatcher' => $vendorDir . '/cweagans/composer-patches/src/Patcher/FreeformPatcher.php',
    'cweagans\\Composer\\Patcher\\GitInitPatcher' => $vendorDir . '/cweagans/composer-patches/src/Patcher/GitInitPatcher.php',
    'cweagans\\Composer\\Patcher\\GitPatcher' => $vendorDir . '/cweagans/composer-patches/src/Patcher/GitPatcher.php',
    'cweagans\\Composer\\Patcher\\PatcherBase' => $vendorDir . '/cweagans/composer-patches/src/Patcher/PatcherBase.php',
    'cweagans\\Composer\\Patcher\\PatcherInterface' => $vendorDir . '/cweagans/composer-patches/src/Patcher/PatcherInterface.php',
    'cweagans\\Composer\\Plugin\\Patches' => $vendorDir . '/cweagans/composer-patches/src/Plugin/Patches.php',
    'cweagans\\Composer\\Resolver' => $vendorDir . '/cweagans/composer-patches/src/Resolver.php',
    'cweagans\\Composer\\Resolver\\Dependencies' => $vendorDir . '/cweagans/composer-patches/src/Resolver/Dependencies.php',
    'cweagans\\Composer\\Resolver\\PatchesFile' => $vendorDir . '/cweagans/composer-patches/src/Resolver/PatchesFile.php',
    'cweagans\\Composer\\Resolver\\ResolverBase' => $vendorDir . '/cweagans/composer-patches/src/Resolver/ResolverBase.php',
    'cweagans\\Composer\\Resolver\\ResolverInterface' => $vendorDir . '/cweagans/composer-patches/src/Resolver/ResolverInterface.php',
    'cweagans\\Composer\\Resolver\\RootComposer' => $vendorDir . '/cweagans/composer-patches/src/Resolver/RootComposer.php',
    'cweagans\\Composer\\Util' => $vendorDir . '/cweagans/composer-patches/src/Util.php',
);
